% STREAMLINES Defines the streamlines of the impeller based
% STREAMLINES(n,m,node,D_2,b_2,D_1,D_1i,A_1,A_2,A2_A1)
% This function is used to find the streamlines in the meridional plane, 
% first streamline is already found, the back shroud of the impeller, 
% from that the other streamlines can be found since the area 
% between parallell streamline is equal 
% out_area_st := the area at outlet divided into m-1 spaces
% dr_temp     := delta r used to find the normal vector
% dz_temp     := delta z used to find the normal vector
% l           := length of the normal vector
% unit_dr     := the delta r length as a unit vector (length as 1)
% unit_dz     := the delta z length as a unit vector (length as 1)
% dl          := total length of the normal vector

function [r,z] = ...
    ax_design_streamlines_diffuser(n,m,D_4,D_3,b_2,b_3,b_4)

R_3 = 0.5*D_3;
R_4 = 0.5*D_4;


%%%%%% Define the nodes %%%%%%%%
% node( # of nodes along str. line ,  ... 
%       # of nodes across str. line, ...
%       (r,theta,z)-coordinates, ...
node = zeros(n,m,3);

z_pos_11    = -b_2-(b_3-b_2)/2;
z_pos_1m    = (b_3-b_2)/2;
z_pos_n1    = -b_2-(b_3-b_2)/2;
z_pos_nm    = b_4-b_3+z_pos_1m;

% Setting the known values of nodes.
node(1,1,:) = [R_3 0 z_pos_11];
node(n,1,:) = [R_4 0 z_pos_n1];
node(1,m,:) = [R_3 0 z_pos_1m];
node(n,m,:) = [R_4 0 z_pos_nm];

xx = linspace(R_3,R_4,n);
yy = linspace(z_pos_11,z_pos_1m,m);

node(:,1,3) = z_pos_11; % Defining one side of the diffuser as horisontal
node(1,:,1) = R_3; % Defining the inlet of the diffuser as radial
node(:,1,1) = xx;
node(1,:,3) = yy;


node(:,m,3)=linspace(z_pos_1m,z_pos_nm,n);

for i=2:n
    for j=1:m
        node(i,j,1) = xx(i);
        node(i,:,3)=linspace(node(i,1,3),node(i,m,3),m); % y-position of node
    end
end

r = node(:,:,1);
z = node(:,:,3);
   
return