function [] = change_line_GH(h,opt,tool)

% function change_line_GH(h,option)
%
% INPUTS:      h = handle to a line object (e.g. created by a plot command)
%         option = [  'x' | 'y' | {'xy'} | 'axy' ]
%
% This function, once enabled, allows the user to manipulate the coordinates of any
% point in a line object specified by handle h, simply by clicking and
% moving the mouse.

declare_global_variables();

switch nargin
case 0
    error('Must Specify a handle to a line object')
case 1
    opt='xy';
case 2
    if ~any(strcmp(opt,{'x','y','xy','axy','a','off'}))
        error(['Second argument ''' opt ''' is an unknown command option.'])
    end
end

if nargin<3  % i.e. user-invoked.  
    b=get(h,'tag');
    if ~isempty(b)&strcmp(b,'change_line_GH')&(nargin==1|strcmp(opt,'off'))  % function being de-invoked
        k=get(h,'userdata');
        %  acw modified to recall buttondownfcn and restore when turned off
        set(h,'buttondownfcn',k.bdfcn,'markersize',k.ms,'marker',k.m,'markerfacecolor',k.mfc,'userdata','','tag','')
    else % function being invoked
        if ~isempty(get(h,'zdata'))
            error('change_line_GH only works for 2-D graphs')
        end
        if strcmp(opt,'a')
            opt='axy';
        end
        if isempty(b) % only assign original values to marker struct if function is being called the first time
            k.m=get(h,'marker');set(h,'marker','o');
            k.ms=get(h,'markersize');set(h,'markersize',4);
            k.mfc=get(h,'markerfacecolor');set(h,'markerfacecolor',get(h,'color'));
        else
            k=get(h,'userdata');
        end
        k.opt=opt;
        k.bdfcn=get(h,'buttondownfcn'); % save the current buttondownfcn before reset
        set(h,'buttondownfcn',['change_line_GH(gco,''' opt ''',1)'],'userdata',k,'tag','change_line_GH');
        set(findobj('children',h),'units','pixels')
    end
else  % i.e. self-invoked
    if strcmp(get(gcf,'selectiontype'),'open')
        change_line_GH(h,'off');
    else
        switch tool
        case 1 % line's buttondownfcn invoked
            if ~isempty(get(h,'zdata'))
                change_line_GH(h)
                error('change_line only works for 2-D graphs')
            end
            cp=get(gca,'currentpoint');
            k=get(h,'userdata');
            y=abs(get(h,'ydata')-cp(2,2));x=abs(get(h,'xdata')-cp(1,1)); % determine which point the user clicked on
            % just use the distance function
            d=sqrt(y.^2+x.^2);
            k.index=find(d==min(d));
            k.axesdata=get(gca,'userdata');
            k.doublebuffer=get(gcf,'doublebuffer');
            k.winbmfcn = get(gcf,'windowbuttonmotionfcn');  %  save current window motion function
            k.winbupfcn = get(gcf,'windowbuttonupfcn');  %  save current window up function
            k.winbdfcn = get(gcf,'windowbuttondownfcn');  %  save current window down function
            
            set(h,'userdata',k);
            set(gcf,'windowbuttonmotionfcn',['change_line_GH(get(gca,''userdata''),''' opt ''',2)'],'doublebuffer','on');
            set(gca,'userdata',h);
            set(gcf,'windowbuttonupfcn',['change_line_GH(get(gca,''userdata''),''' opt ''',3)']);
            
            %         end    
        case 2 % button motion function
            k=get(h,'userdata');
            cp=get(gca,'currentpoint');
            x=get(h,'xdata');
            y=get(h,'ydata');
            switch opt
            case 'x'
                x(k.index)=cp(1,1);
            case 'y'
                y(k.index)=cp(2,2);
            case {'xy','axy'}
                x(k.index)=cp(1,1);
                y(k.index)=cp(2,2);
            end
            
            if (~strcmp(opt,'axy')&~strcmp(opt,'x'))
                if k.index>1&x(k.index)<x(k.index-1)
                    x(k.index)=x(k.index-1);
                end
                if k.index<length(x)&x(k.index)>x(k.index+1)
                    x(k.index)=x(k.index+1);
                end
            end
            
            set(h,'xdata',x,'ydata',y)
            % test to see if it moved off the screen - update limits
            fgx=get(gca,'xlim');
            fgy=get(gca,'ylim');
            if any(opt=='y')&cp(2,2)>fgy(2)
                set(gca,'ylim',[fgy(1) cp(2,2)])
            end
            if any(opt=='y')&cp(2,2)<fgy(1)
                set(gca,'ylim',[cp(2,2) fgy(2)])
            end
            if any(opt=='x')&cp(1,1)>fgx(2)
                set(gca,'xlim',[fgx(1) cp(1,1)])
            end
            if any(opt=='x')&cp(1,1)<fgx(1)
                set(gca,'xlim',[cp(1,1) fgx(2)])
            end
            
        case 3 % button up - we're done
            
            % Update GH curve
            Px=get(h,'Xdata');
            Py=get(h,'Ydata');
            
			% Setting the outlet angle at Beta_2 to the pump beta_2 design value
            Py(2) = tand(valg_design_beta2)*Px(2);
            set(h,'YData',Py);
            
            valg_design_bezier_H=Px; valg_design_bezier_G=Py;
            [Qx_temp,Qy_temp] = Funct_Bezier_unplot(Px,Py,valg_npoints_cross-1);
            [Qx,Qy] = even_spaces(Qx_temp,Qy_temp,valg_npoints_cross);

            set(hand_plot_GH1,'XData',Qx,'YData',Qy);
            
            polynom_spline_GH = spline(Qx,Qy);
			
			[param_angle_dist_ring] = get_spline_angle(polynom_spline_GH);
			out_angle = param_angle_dist_ring(1);
			in_angle  = param_angle_dist_ring(end);
            
            % Show Beta2 values on GH-plot
            % angle=atand(gradient2(Qy,Qx));
            dx=-0.1*cosd(out_angle);
            dy=-0.1*sind(out_angle);
            set(hand_plot_GH_Beta2,'XData',[Qx(1) Qx(1)+dx], ...
                'YData',[Qy(1) Qy(1)+dy]);
            set(hand_plot_GH_Beta2_text, ...
                'Position',[Qx(1)+dx Qy(1)+dy], ...
                'String',['\beta_{2,ring} = ',num2str(out_angle,3),'^o']);

            % Show Beta1 value on GH-plot
            % ant=length(Qx);
            dx=0.1*cosd(in_angle);
            dy=0.1*sind(in_angle);
            set(hand_plot_GH_Beta1,'XData',[Qx(end) Qx(end)+dx], ...
                'YData',[Qy(end) Qy(end)+dy]);
            set(hand_plot_GH_Beta1_text, ...
                'Position',[Qx(end)+dx Qy(end)+dy], ... 
                'String',['\beta_{1.ring} = ',num2str(in_angle,3),'^o']);
            
            % Update the values for the beta1 & beta2 in the angles frame
            set(hand_calc_axdesign_beta2,'String',num2str(out_angle));
            set(hand_calc_axdesign_beta1,'String',num2str(in_angle));
            
            % Update the radial cut view
            [valg_ax_nodes(:,:,2),param_beta,param_f,param_g,param_h] =  ...
                find_theta( ...
                    valg_npoints_cross, ...
                    valg_npoints_stream, ...
                    valg_ax_nodes(:,:,1), ...
                    valg_ax_nodes(:,:,3), ...
			        out_angle, ...
			        get(hand_calc_Cm1_ring,'Value'), ...
			        param_angle_dist_ring, ...
                    param_omega, ...
                    param_dA_n ...
                );
            
            x_rad_view = valg_ax_nodes(:,:,1).*sind(valg_ax_nodes(:,:,2));
            y_rad_view = valg_ax_nodes(:,:,1).*cosd(valg_ax_nodes(:,:,2));

            midp = round(0.5*valg_npoints_stream);
            set(hand_plot_rad_cut_ring, ...
                'XData',x_rad_view(:,1), ...
                'YData',y_rad_view(:,1));
            
            set(hand_plot_rad_cut_mid, ...
                'XData',x_rad_view(:,midp), ...
                'YData',y_rad_view(:,midp));
            
            set(hand_plot_rad_cut_boss, ...
                'XData',x_rad_view(:,end), ....
                'YData',y_rad_view(:,end));
            
            r_max = max(max(valg_ax_nodes(:,:,1)));
            set(hand_plot_rad, ...
                'XLim',[-r_max r_max], ...
                'YLim',[-r_max r_max], ...
                'DataAspectRatio',[1 1 1]);
                
			for j=1:valg_npoints_cross;
			set(hand_plot_rad_cut_cross(j), ...
				'XData',x_rad_view(j,:), ...
				'YData',y_rad_view(j,:));
			end
                
                      
            %Update the Velocity loads plot
            [param_g,param_g_sum,valg_ax_nodes_xyz] = ...
                find_G( ...
                    valg_npoints_cross, ...
                    valg_npoints_stream, ...
                    valg_ax_nodes, ...
                    param_beta, ...
                    valg_design_beta2, ...
                    str2num(get(hand_calc_beta1_ring,'String')) ...
                );
                
            [U_nodes,Cm_nodes,W_nodes,WU_nodes,CU_nodes, ...
              param_f_sum,param_h_sum] = ... 
                find_velocity_loads(...
                    valg_npoints_cross, ...
                    valg_npoints_stream, ...
                    valg_ax_nodes, ...
                    param_g, ...
                    param_g_sum, ...
                    param_omega, ...
                    param_dA_n, ...
                    valg_design_flow, ...
                    param_beta, ...
                    param_f, ...
                    param_g, ...
                    param_h ...
                );

            s = param_f_sum;
            param_velocity_load = CU_nodes.*U_nodes;
            s_end = s(end,:);


            set(hand_plot_velocity_load_ring, ...
                'XData',s(:,1)/s_end(1), ...
                'YData',param_velocity_load(:,1));
            set(hand_plot_velocity_load_mid, ...
                'XData',s(:,midp)/s_end(midp), ...
                'YData',param_velocity_load(:,midp));
            set(hand_plot_velocity_load_boss, ...
                'XData',s(:,valg_npoints_stream)/s_end(end), ...
                'YData',param_velocity_load(:,valg_npoints_stream));

			for j=1:valg_npoints_cross
				set(hand_plot_velocity_load_cross(j), ...
					'XData',s(j,:)./s_end, ...
					'YData',param_velocity_load(j,:));
			end

            
            k=get(h,'userdata');
            set(gca,'userdata',k.axesdata); % restore axes data to its previous value
            set(gcf,'windowbuttonmotionfcn',k.winbmfcn,'windowbuttonupfcn',k.winbupfcn,'doublebuffer',k.doublebuffer)
            
            
        end
    end
end
