function [h_axes,h_design_calc,x_limit,y_limit] =  ...
	draw_charac_curves_trad_3(h_axes,Q_design,U_2,U_1,C_U2,D_2,D_1,b_2,beta_2,beta_1,A_1,slipcoeff,omega,fric,shock,g,Z,H,nq)

set(gcf,'CurrentAxes',h_axes)

% Parameters used in the calculations
R_2 = 0.5*D_2;
A_2 = R_2*2*pi*b_2;

% Some dimensions
a1      = 0.018;        % Inlet throat dimension (estimated)
b1      = 0.0324;       % Inlet throat dimension
a2      = 0.04;         % Outlet throat dimension (estimated)
b2      = 0.013;        % Outlet height
Lsch    = 0.14;         % Impeller blade length (estimated)
visc    = 0.553*10^-6;  % Kinematic viscosity water 50C
eps     = 0.5*10^-3;    % Absolute roughness of moderately corroded carbon steel (http://neutrium.net/fluid_flow/absolute-roughness/)
a3      = 0.0127;       % Diffuser inlet throat width
b3      = 0.0155;       % Diffuser inlet throat height
a4      = 0.0276;       % Diffuser outlet throat width
b4      = 0.0184;       % Diffuser outlet throat height
cp      = 0.72;         % Diffuser cp from figure
Z_Le    = 10;           % Diffuser vanes
zetaov  = 1.5;          % Return channel design coefficient, between 0.2 and 1.5. 0.2 is good design, 1.0 is bad design

Q = 0;
step_size = Q_design/100;
i = 1;
Q_Lopt=2*4.1/(nq^1.6)*Q_design;
Ku=Q_Lopt/sqrt(H);

A_R        = (a4*b4)/(a3*b3);
Dh         = (2*(a2*b2+a1*b1))/(a1+b1+a2+b2);


W_U2temptemp       = (Q/A_2) / tand(beta_2); % should be 0 (zero)
C_U2temptemp       = U_2-W_U2temptemp;
Htemptemp  = (U_2/g)*C_U2temptemp;
Q_L        = Ku*sqrt(Htemptemp);
W_Q1       = (Q+Q_L)/(Z*a1*b1);
W_U1       = ((Q+Q_L)/A_1) / tand(beta_1);
C_U1       = U_1-W_U1;
C_M1       = (Q+Q_L)/A_1;
W_M1       = sqrt(C_M1^2+(U_1-C_U1)^2);
h_Las      = 0.3/(2*g)*(W_M1-W_Q1)^2;
W_av       = 2*(Q+Q_L)/(Z*(a2*b2+a1*b1));
Re         = W_av*Lsch/visc;
cf         = 0.136/((-log10(0.2*eps/Lsch+12.5/Re))^2.15);
cd         = (cf+0.0015)*(1.1+4*b2/D_2);
h_Laf      = 2*cd/g*Lsch/Dh*W_av^2;
h_La       = h_Las+h_Laf; % Total impeller loss
W_U2       = ((Q+Q_L)/A_2) / tand(beta_2);
C_U2       = U_2-W_U2;
C_U2slip   = slipcoeff*U_2-W_U2;
C_M2       = (Q+Q_L)/A_2;
C_2slip    = sqrt(C_M2^2+C_U2slip^2);
C_Q3       = (Q+0.5*Q_L)/(Z_Le*a3*b3);
h_23       = U_2^2/(2*g)*(cf+0.0015)*(a3/D_2+b3/D_2)*pi^3*((C_M2*b2)/(U_2*D_2))^2/(8*(Z_Le*(a3*b3)/(D_2)))^3*(1+C_2slip/C_Q3)^3;
h_Le       = h_23+C_Q3^2/(2*g)*(0.3*(C_2slip/C_Q3-1)^2+1-cp-(1-zetaov)/A_R^2); % Total diffuser loss
h_th_inf   = (U_2/g)*C_U2; % U_2^2/g
h_th       = (U_2/g)*C_U2slip;
h          = h_th - h_La-h_Le;


Q = Q+step_size;

while (Q<(2*Q_design))
    W_U2temptemp    = (Q/A_2) / tand(beta_2); % should be 0 (zero)
    C_U2temptemp    = U_2-W_U2temptemp;
    Htemptemp       = (U_2/g)*C_U2temptemp;
    Q_L_temp        = Ku*sqrt(Htemptemp);
	W_U2_temp       = ((Q+Q_L_temp)/A_2)/tand(beta_2);
    W_Q1_temp       = (Q+Q_L_temp)/(Z*a1*b1);
	W_U1_temp       = ((Q+Q_L_temp)/A_1)/tand(beta_1);
	C_U2_temp 	    = U_2-W_U2_temp;
	C_U2slip_temp   = slipcoeff*U_2-W_U2_temp;
	C_U1_temp       = U_1-W_U1_temp;
    C_M1_temp       = (Q+Q_L_temp)/A_1;
    W_M1_temp       = sqrt(C_M1_temp^2+(U_1-C_U1_temp)^2);
    h_Las_temp      = 0.3/(2*g)*(W_M1_temp-W_Q1_temp)^2;
    W_av_temp       = 2*(Q+Q_L_temp)/(Z*(a2*b2+a1*b1));
    Re_temp         = W_av_temp*Lsch/visc;
    cf_temp         = 0.136/((-log10(0.2*eps/Lsch+12.5/Re_temp))^2.15);
    cd_temp         = (cf_temp+0.0015)*(1.1+4*b2/D_2);
    h_Laf_temp      = 2*cd_temp/g*Lsch/Dh*W_av_temp^2;
    h_La_temp       = h_Las_temp+h_Laf_temp; % Total impeller loss
    C_M2_temp       = (Q+Q_L_temp)/A_2;
    C_2slip_temp    = sqrt(C_M2_temp^2+C_U2slip^2);
    C_Q3_temp       = (Q+0.5*Q_L_temp)/(Z_Le*a3*b3);
    h_23_temp       = U_2^2/(2*g)*(cf_temp+0.0015)*(a3/D_2+b3/D_2)*pi^3*((C_M2_temp*b2)/(U_2*D_2))^2/(8*(Z_Le*(a3*b3)/(D_2)))^3*(1+C_2slip_temp/C_Q3_temp)^3;
    h_Le_temp       = h_23_temp+C_Q3_temp^2/(2*g)*(0.3*(C_2slip_temp/C_Q3_temp-1)^2+1-cp-(1-zetaov)/A_R^2); % Total diffuser loss
	h_th_inf_temp   = (U_2/g)*(C_U2_temp);
	h_th_temp       = (U_2/g)*(C_U2slip_temp);  
	h_temp          = h_th_temp - h_La_temp-h_Le_temp;

	[W_U2]          = [W_U2       W_U2_temp];
	[h_th_inf]      = [h_th_inf   h_th_inf_temp];
	[h_th]          = [h_th       h_th_temp];
    [h_Le]          = [h_Le       h_Le_temp];
    [h_La]          = [h_La       h_La_temp];
	[h]             = [h          h_temp];
    
	Q = Q+step_size;
	i = i+1;
end

Q = linspace(0,Q,length(h_th_inf));

% [min_dh_shock,min_index] = min(h_Le);
h_design_calc = h(101);



x_limit = Q(end);
y_limit = h_th_inf(1);

plot(h_axes,Q,h_th_inf,'g', ...
	 Q,h_th,'m', ...
	 Q,h_Le,':b', ...
	 Q,h,'r', ...
	 Q,h_La,':k', ...
	 [0 9.9 20.3 30.2 39.9 50.1 59.7 70.6 80.2 90.2 101]/3600,[75.22 74.03 72.67 71.16 68.40 66.02 61.99 56.71 50.54 43.65 35.62]/3,'k', ...
     [Q_design Q_design],[0 max(h_th_inf)],'c:')
 
legend('H_{th\infty}','H_{th}','\DeltaH_{diffuser}','H','\DeltaH_{impeller}','H_{measured}')
set(h_axes,'XLim',[0 x_limit],'YLim',[0 y_limit]);

xlabel('Q [m^3/s]'); 
ylabel('H [m]');
