function [X,Y] = ellipse(a,b,x0,y0,theta1,theta2,n)
%ELLIPSE can draw an arbitrary ellipse with given parameters.
%   The properties of that ellipse plot can be customized 
%   by setting the ellipse handle. 
%
%       hEllipse = ellipsedraw(a,b,x0,y0,theta1,theta2)
%
%   Input parameters:
%       a           Value of the major axis
%       b           Value of the minor axis
%       x0          Abscissa of the center point of the ellipse
%       y0          Ordinate of the center point of the ellipse
%       theta1      Start theta
%       theta2   	End theta
%
% Designed by: Lei Wang, <WangLeiBox@hotmail.com>, 25-Mar-2003.
% Last Revision: 01-Apr-2003.
% Dept. Mechanical & Aerospace Engineering, NC State University.
% Copyright (c)2003, Lei Wang <WangLeiBox@hotmail.com>
%$Revision: 1.0 $  $ 4/1/2003 5:42:24 PM $

if (nargin < 2)|(nargin > 7),
    error('Please see help for INPUT DATA.');
end


theta = linspace(theta1,theta2,n);

% Parametric equation of the ellipse
%----------------------------------------
x = a*cosd(theta);
y = b*sind(theta);


% Coordinate transform 
%----------------------------------------
X = x + x0;
Y = y + y0;

return


