% FIND_G Finds G, which is the streamline length in the meridional plane
% FIND_G(n,m,node,beta,beta_2,beta1)
% This function is used to find G, G is the length of the streamlines in the
% rz-plane
% G     := Length of the streamlines in the rz-plane
% G_sum := Accumlative length of the steamlines in the rz-plane
% xyz   := Coordinates of the points of the impeller in (x,y,z) instead of
%          (r,theta,z)
function [G,G_sum,xyz] = ...
    find_G(n,m,node,beta,beta_2,beta1)

x = node(:,:,1).*sind(beta(:,:));
y = node(:,:,1).*cosd(beta(:,:));
z = node(:,:,3);
zyx = zeros(n,m,3);
xyz(:,:,1) = x;
xyz(:,:,2) = y;
xyz(:,:,3) = z;

G = zeros(n-1,m);
for i=1:n-1
    dx = x(i,:)-x(i+1,:);
    dy = y(i,:)-y(i+1,:);
    dz = z(i,:)-z(i+1,:);
    G(i,:) = sqrt(dx.^2+dy.^2+dz.^2);
end

G_merid = G(:,round(m/2));

G_sum = zeros(n,m);
G_temp = zeros(1,m);
for i=2:n
    G_sum(i,:) = G_temp+G(i-1,:);
    G_temp = G_sum(i,:);

end

G_merid_sum = G_sum(:,round(m/2));
