function [theta,beta,f,g,h] = find_theta(n,m,r,z,beta_2,C_1m,ring_angles,omega,dA_n);

% g is the length of the streamline in the axial view
% h is the length of the streamline in the radial view
% f is the real length of the streamline in 3D
% theta is the angle between points in the radial view from the origin
% 

beta        = zeros(n  ,m);
f           = zeros(n-1,m);
g           = zeros(n-1,m);
sum_g       = zeros(1  ,m);
h           = zeros(n-1,m);
dtheta      = zeros(n-1,m);
dtheta_sum  = zeros(n-1,m);
dtheta_temp = zeros(1  ,m);

Areals = dA_n/n;

for i=1:n-1;
    for j=1:m;
        dr = r(i,j)-r(i+1,j);
        dz = z(i,j)-z(i+1,j);
        g(i,j) = sqrt(dr^2+dz^2);
    end;
end;

beta(1,:) = beta_2; % set angle at outlet to beta_2
beta(n,:) = atand(C_1m./((r(n,:)*omega))); % set the angle at inlet f(r,omega)

dAngles = ring_angles(end)-ring_angles(1);
ring_angles_normalized = (ring_angles-ring_angles(1))/dAngles;

for i=1:m
	dAngles = beta(end,i)-beta(1,i);
	beta(:,i) = ring_angles_normalized(:)*dAngles+beta(1,i);
end

for j=1:m;
    [dfx] = gradient2(z(:,j),r(:,j));
    angles = atand(dfx);
    g_temp = 0;
    sum_g(j) = sum(g(:,j));
    dAreals(j) = Areals(j)/(m-1);
    for i=2:n;
        g_temp = g_temp + g(i-1,j);
        % beta(i,j) = g_temp/sum_g(j)*(beta(n,j)-beta(1,j))+beta(1,j);
    end;
end;

for i=1:n-1; 
    for j=1:m;
        f(i,j) = g(i,j)/sind(beta(i,j));
        h(i,j) = g(i,j)/tand(beta(i,j));
    end; 
end;

dtheta = (h*360)./(2*pi*r(1:n-1,:));

for i=1:n-1
    dtheta_sum(i,:) = dtheta(i,:)+dtheta_temp;
    dtheta_temp = dtheta_sum(i,:);
end

theta(2:n,:) = dtheta_sum;
