% FIND_VELOCITY_LOADS finds the velocity loads (U*C_m)
% FIND_VELOCITY_LOADS(n,m,node,G,G_sum,omega,dA_n,Q,beta,f,g,h)
% This function is used to find the load on the impeller, U*C_m.
% (Preferably the loads should be small near the inlet and outlet)
% U          := Peripherial velocity
% C_m        := Meridional component of absolute velocity (Q/A)
% W          := Relavite velocity 
% W_U        := Peripheral component of the relative velocity
% C_U        := Peripheral component of the absolute velocity
% f          := Length of the streamline in meridional plane
% f_sum      := Accumulative length of the steamline in meridional plane
% s          := The 3D length of the streamline, uses f and G
% load_param := The load of the impeller (U*C_U)

function [U,C_m,W,W_U,C_U,f_sum,h_sum] = ...
    find_velocity_loads(n,m,node,G,G_sum,omega,dA_n,Q,beta_nodes,f,g,h)

r = node(:,:,1);
z = node(:,:,3);

U   = zeros(n,m);
C_m = zeros(n,m);

U = omega*r;
for i=1:n
    C_m(i,:) = Q/dA_n(i);
end

f_sum = zeros(n,m);
f_temp = zeros(1,m);
h_sum = zeros(n,m);
h_temp = zeros(1,m);

for i=2:n
    f_sum(i,:) = f_temp+f(i-1,:);
    f_temp = f_sum(i,:);
    h_sum(i,:) = h_temp+h(i-1,:);
    h_temp = h_sum(i,:);

end

% s = sqrt(f_sum.^2+G_sum.^2);

W = C_m./sind(beta_nodes);
W_U = C_m./tand(beta_nodes);
C_U = U-W_U;
load_param = C_U.*U;

return;