% declare_global_variables;

node = valg_ax_nodes;
r = node(:,:,1);
x = node(:,:,1).*sind(node(:,:,2));
y = node(:,:,1).*cosd(node(:,:,2));
z = node(:,:,3);

% Set the outlet, middle and inlet sections of the vane into a single matrix
suction_side_f_param    = [suct_x_outlet; param_f_sum(2:inlet_suct_last_node,:);             suct_x_inlet];
suction_side_thickness  = [suct_y_outlet; 0.5*impeller_thickness(2:inlet_suct_last_node,:);  suct_y_inlet];
pressure_side_f_param   = [pres_x_outlet; param_f_sum(2:inlet_pres_last_node,:);             pres_x_inlet];
pressure_side_thickness = [pres_y_outlet; -0.5*impeller_thickness(2:inlet_pres_last_node,:); pres_y_inlet];


param_g_sum_suction  = zeros(size(suction_side_f_param));
param_h_sum_suction  = zeros(size(suction_side_f_param));
param_g_sum_pressure = zeros(size(pressure_side_f_param));
param_h_sum_pressure = zeros(size(pressure_side_f_param));


[n_suct,m_suct] = size(suction_side_f_param);
[n_pres,m_pres] = size(pressure_side_f_param);
suction_nodes = zeros(n_suct,m_suct,3);
pressure_nodes = zeros(n_pres,m_pres,3);

suction_nodes_pol = zeros(n_suct,m_suct,3);
pressure_nodes_pol = zeros(n_pres,m_pres,3);

% Set the positions of datapoints along the streamline where the thickness values are given
for i=1:valg_npoints_stream
	param_g_sum_suction(:,i) = spline(param_f_sum(:,i),param_g_sum(:,i),suction_side_f_param(:,i));
	param_h_sum_suction(:,i) = spline(param_f_sum(:,i),param_h_sum(:,i),suction_side_f_param(:,i));
	param_f_sum_suction(:,i) = spline(param_f_sum(:,i),sqrt(param_g_sum(:,i).^2+param_h_sum(:,i).^2),suction_side_f_param(:,i));
	
	suction_nodes(:,i,1) = spline(param_g_sum(:,i),x(:,i),param_g_sum_suction(:,i));
	suction_nodes(:,i,2) = spline(param_g_sum(:,i),y(:,i),param_g_sum_suction(:,i));
	suction_nodes(:,i,3) = spline(param_g_sum(:,i),z(:,i),param_g_sum_suction(:,i));
	
	param_g_sum_pressure(:,i) = spline(param_f_sum(:,i),param_g_sum(:,i),pressure_side_f_param(:,i));
	param_h_sum_pressure(:,i) = spline(param_f_sum(:,i),param_h_sum(:,i),pressure_side_f_param(:,i));
	param_f_sum_pressure(:,i) = spline(param_f_sum(:,i),sqrt(param_g_sum(:,i).^2+param_h_sum(:,i).^2),pressure_side_f_param(:,i));
	
	pressure_nodes(:,i,1) = spline(param_g_sum(:,i),x(:,i),param_g_sum_pressure(:,i));
	pressure_nodes(:,i,2) = spline(param_g_sum(:,i),y(:,i),param_g_sum_pressure(:,i));
	pressure_nodes(:,i,3) = spline(param_g_sum(:,i),z(:,i),param_g_sum_pressure(:,i));
end

% Change the xyz-coordinates of the nodes to polar-coordinates
[suction_nodes_pol(:,:,2),suction_nodes_pol(:,:,1),suction_nodes_pol(:,:,3) ] ...
		= cart2pol(suction_nodes(:,:,1),suction_nodes(:,:,2),suction_nodes(:,:,3));
suction_nodes_pol(:,:,2) = -suction_nodes_pol(:,:,2)*180/pi+90;
[pressure_nodes_pol(:,:,2),pressure_nodes_pol(:,:,1),pressure_nodes_pol(:,:,3) ] ...
		= cart2pol(pressure_nodes(:,:,1),pressure_nodes(:,:,2),pressure_nodes(:,:,3));
pressure_nodes_pol(:,:,2) = -pressure_nodes_pol(:,:,2)*180/pi+90;

nvanes = length(hand_surf_vanes);
[n,m] = size(get(hand_surf_vanes(1),'XData'));
suct_surf = zeros(n_suct,m_suct,3,nvanes);
pres_surf = zeros(n_pres,m_pres,3,nvanes);

% Find the normal vectors of the vanes and
% set the thickness of the vanes
% and find the xyz-coordinates of the vane
for i=1:nvanes

    [norm_x_suct(:,:,i),norm_y_suct(:,:,i),norm_z_suct(:,:,i)] = ...
        surfnorm(suction_nodes(:,:,1),suction_nodes(:,:,2),suction_nodes(:,:,3));
    suct_surf(:,:,1,i) = suction_nodes(:,:,1)- norm_x_suct(:,:,i).*suction_side_thickness(:,:);
    suct_surf(:,:,2,i) = suction_nodes(:,:,2)- norm_y_suct(:,:,i).*suction_side_thickness(:,:);
    suct_surf(:,:,3,i) = suction_nodes(:,:,3)- norm_z_suct(:,:,i).*suction_side_thickness(:,:);


    [norm_x_pres(:,:,i),norm_y_pres(:,:,i),norm_z_pres(:,:,i)] = ...
        surfnorm(pressure_nodes(:,:,1),pressure_nodes(:,:,2),pressure_nodes(:,:,3));
    pres_surf(:,:,1,i) = pressure_nodes(:,:,1)-norm_x_pres(:,:,i).*pressure_side_thickness(:,:);
    pres_surf(:,:,2,i) = pressure_nodes(:,:,2)-norm_y_pres(:,:,i).*pressure_side_thickness(:,:);
    pres_surf(:,:,3,i) = pressure_nodes(:,:,3)-norm_z_pres(:,:,i).*pressure_side_thickness(:,:);

end

suct_surf_pol = zeros(n_suct,m_suct,3);
pres_surf_pol = zeros(n_pres,m_pres,3);

[suct_surf_pol(:,:,2), suct_surf_pol(:,:,1), suct_surf_pol(:,:,3)] = cart2pol(suct_surf(:,:,1),suct_surf(:,:,2),suct_surf(:,:,3));
[pres_surf_pol(:,:,2), pres_surf_pol(:,:,1), pres_surf_pol(:,:,3)] = cart2pol(pres_surf(:,:,1),pres_surf(:,:,2),pres_surf(:,:,3));
suct_surf_pol(:,:,2) = -suct_surf_pol(:,:,2)*180/pi+90;
pres_surf_pol(:,:,2) = -pres_surf_pol(:,:,2)*180/pi+90;

% quiver3(suct_surf(:,:,1),suct_surf(:,:,2),suct_surf(:,:,3),norm_x_suct(:,:,1),norm_y_suct(:,:,1),norm_z_suct(:,:,1));
% quiver3(pres_surf(:,:,1),pres_surf(:,:,2),pres_surf(:,:,3),norm_x_pres(:,:,1),norm_y_pres(:,:,1),norm_z_pres(:,:,1));


% Draw the vanes in 3D in 3D View, separately for suction and pressure side
[hand_axes_3Dview,hand_surf_suction]  = draw_vanes(hand_axes_3Dview,valg_design_Z,param_Z_drawn,suct_surf_pol);
[hand_axes_3Dview,hand_surf_pressure] = draw_vanes(hand_axes_3Dview,valg_design_Z,param_Z_drawn,pres_surf_pol);