declare_global_variables;

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Design parameter
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
n = valg_design_rotspeed;
param_omega = n*2*pi/60;
Q = valg_design_flow;
H = valg_design_nethead;
g = valg_design_gP;

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate specific speeds
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
n_sQ = n*Q^0.5/H^0.75;
n_sstar = n_sQ/g^0.75;
n_sQstar = (1000/60)*n_sstar;

set(hand_calc_sp_speed, ...
    'String',num2str(0.1*round(10*n_sQ)), ...
    'Value',n_sQ);

set(hand_calc_sp_speed_dimless, ...
    'String',num2str(0.1*round(10*n_sstar)), ...
    'Value', n_sstar);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Calculate outlet values
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate outlet area
% A_2 not taking into account vane thickness
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%psi_opt=1.21*exp(-0.77*n_sQ/100); % Head coefficient

%D_2     = 60/(pi*n)*sqrt(2*g*H/psi_opt); %Beregning av D_2 fra gulich
D_2     = valg_design_D2;
R_2     = 0.5*D_2;
D_2_red = D_2/R_2; % Should be 2
R_2_red = 0.5*D_2_red; % Defined as 11

%set(hand_calc_D2, ...
%    'String',num2str(D_2), ...
%    'Value',D_2); %Beregning av D_2 fra gulich
%valg_design_D2=D_2; %Beregning av D_2 fra gulich

b_2     = valg_design_b2;
b_2_red = b_2/R_2;
set(hand_value_b2, ...
    'String',num2str(b_2), ...
    'Value',b_2);

A_2     = R_2    *2*pi*b_2;
A_2_red = R_2_red*2*pi*b_2_red; % A_2/A_2; % Defined as 1
param_A2     = A_2;
param_A2_red = A_2_red; 
set(hand_calc_A2, ...
    'String',num2str(A_2), ...
    'Value',A_2);





%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate Peripherial velocity, U_2
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
U_2     = R_2*param_omega;
U_2_red = U_2/U_2; % Defined as 1;
set(hand_calc_U2, ...
    'String',num2str(U_2), ...
    'Value',U_2);
set(hand_calc_U2_red, ...
    'String',num2str(U_2_red), ...
    'Value',U_2_red);
set(hand_calc_U2slip, ...
    'String',num2str(U_2), ...
    'Value',U_2);
set(hand_calc_U2slip_red, ...
    'String',num2str(U_2_red), ...
    'Value',U_2_red);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate outlet meridional velocity component of absolute velocity, C_m2
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
C_m2     = Q/A_2;
C_m2_red = C_m2/U_2;
set(hand_calc_Cm2, ...
    'String',num2str(C_m2), ...
    'Value',C_m2);
set(hand_calc_Cm2_red, ...
    'String',num2str(C_m2_red), ...
    'Value',C_m2_red);
set(hand_calc_Cm2slip, ...
    'String',num2str(C_m2), ...
    'Value',C_m2);
set(hand_calc_Cm2slip_red, ...
    'String',num2str(C_m2_red), ...
    'Value',C_m2_red);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate relative outlet velocity, W_2
% also setting the W_2slip values
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
beta_2  = valg_design_beta2;

W_2     = C_m2/sind(beta_2);
W_2_red = W_2/U_2;
set(hand_calc_W2, ...
    'String',num2str(W_2), ...
    'Value',W_2);
set(hand_calc_W2_red, ...
    'String',num2str(W_2_red), ...
    'Value',W_2_red);


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate outlet peripheral velocity component of relative velocity, W_U2
% also setting the W_U2slip values
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
W_U2     = C_m2/tand(beta_2);
W_U2_red = W_U2/U_2;
set(hand_calc_WU2, ...
    'String',num2str(W_U2), ...
    'Value',W_U2);
set(hand_calc_WU2_red, ...
    'String',num2str(W_U2_red), ...
    'Value',W_U2_red);



%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate C_U2
% also setting the W_U2slip values
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
C_U2     = U_2-W_U2;
C_U2_red = C_U2/U_2;
set(hand_calc_CU2, ...
    'String',num2str(C_U2), ...
    'Value',C_U2);
set(hand_calc_CU2_red, ...
    'String',num2str(C_U2_red), ...
    'Value',C_U2_red);





%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Calculate inlet values
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate impeller eye diameter, D_1
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

D_1       = valg_design_D1;
D_1i      = valg_design_D1i;
D_n       = valg_design_Dn;
R_1i      = 0.5*D_1i;
D_1i_red  = D_1i/R_2;
D_n_red   = D_n/R_2;
R_1i_red  = 0.5*D_1i_red;
R_n_red   = 0.5*D_n_red;
R_1       = 0.5*D_1;
D_1_red   = D_1/R_2;
R_1_red   = 0.5*D_1_red;
set(hand_calc_D1, ...
    'String',num2str(D_1), ...
    'Value',D_1);



%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate inlet area, A_1
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
A_1     = (pi)/4*(D_1^2-D_n^2);
A2_A1   = A_2/A_1;
A_1_red = A_2_red/A2_A1;



set(hand_calc_A1, ...
    'String',num2str(A_1), ...
    'Value',A_1);

set(hand_calc_ratA, ...
    'String',num2str(A2_A1), ...
    'Value',A2_A1);

param_A1     = A_1;
param_A1_red = A_1_red;


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate inlet mean streamline diamter, D_1m
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
D_1m     = sqrt((D_1^2+D_1i^2)*0.5);
D_1m_red = D_1m/R_2;
set(hand_calc_D1m, ...
    'String',num2str(D_1m), ....
    'Value',D_1m);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate inlet circumferential velocity, U_1
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
U_1_ring     = param_omega*D_1*0.5;
U_1_ring_red = U_1_ring/U_1_ring; % Defined as 1
set(hand_calc_U1_ring, ...
    'String',num2str(U_1_ring), ...
    'Value',U_1_ring);
set(hand_calc_U1_ring_red, ...
    'String',num2str(U_1_ring_red), ...
    'Value',U_1_ring_red);

U_1_merid     = param_omega*D_1m*0.5;
U_1_merid_red = U_1_merid/U_1_ring;
set(hand_calc_U1_merid, ...
    'String',num2str(U_1_merid), ...
    'Value',U_1_merid);
set(hand_calc_U1_merid_red, ...
    'String',num2str(U_1_merid_red), ...
    'Value',U_1_merid_red);

U_1_boss     = param_omega*D_1i*0.5;
U_1_boss_red = U_1_boss/U_1_ring;
set(hand_calc_U1_boss, ...
    'String',num2str(U_1_boss), ...
    'Value',U_1_boss);
set(hand_calc_U1_boss_red, ...
    'String',num2str(U_1_boss_red), ...
    'Value',U_1_boss_red);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate inlet meridional component of absolute velocity, C_m1
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
C_m1_ring = Q/A_1;
C_m1_ring_red = C_m1_ring/U_1_ring;
set(hand_calc_Cm1_ring, ...
    'String',num2str(C_m1_ring), ...
    'Value',C_m1_ring);
set(hand_calc_Cm1_ring_red, ...
    'String',num2str(C_m1_ring_red), ...
    'Value',C_m1_ring_red);

C_m1_merid = Q/A_1;
C_m1_merid_red = C_m1_merid/U_1_ring;
set(hand_calc_Cm1_merid, ...
    'String',num2str(C_m1_merid), ...
    'Value',C_m1_merid);
set(hand_calc_Cm1_merid_red, ...
    'String',num2str(C_m1_merid_red), ...
    'Value',C_m1_merid_red);

C_m1_boss = Q/A_1;
C_m1_boss_red = C_m1_boss/U_1_ring;
set(hand_calc_Cm1_boss, ...
    'String',num2str(C_m1_boss), ...
    'Value',C_m1_boss);
set(hand_calc_Cm1_boss_red, ...
    'String',num2str(C_m1_boss_red), ...
    'Value',C_m1_boss_red);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate angle of inlet at boss, beta_1
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
beta_1_ring = atand(C_m1_ring/U_1_ring);
set(hand_calc_beta1_ring, ...
    'String',num2str(beta_1_ring), ...
    'Value',beta_1_ring);

beta_1_merid = atand(C_m1_merid/U_1_merid);
set(hand_calc_beta1_merid, ...
    'String',num2str(beta_1_merid), ...
    'Value',beta_1_merid);

beta_1_boss = atand(C_m1_boss/U_1_boss);
set(hand_calc_beta1_boss, ...
    'String',num2str(beta_1_boss), ...
    'Value',beta_1_boss);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate other usesful velocities
% C_U1 at ring, merid and boss
% W_1 at ring, merid and boss
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
C_U1_ring  = U_1_ring - Q/(A_1*tand(beta_1_ring));
C_U1_merid = U_1_merid- Q/(A_1*tand(beta_1_merid));
C_U1_boss  = U_1_boss - Q/(A_1*tand(beta_1_boss));
W_1_ring   = C_U1_ring/ sind(beta_1_ring );
W_1_merid  = C_U1_merid/sind(beta_1_merid);
W_1_boss   = C_U1_boss/ sind(beta_1_boss );

C_U1_ring_red  = C_U1_ring /U_1_ring;
C_U1_merid_red = C_U1_merid/U_1_ring;
C_U1_boss_red  = C_U1_boss /U_1_ring;
W_1_ring_red   = W_1_ring  /U_1_ring;
W_1_merid_red  = W_1_merid /U_1_ring;
W_1_boss_red   = W_1_boss  /U_1_ring;


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Calculate slip values
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

Z       = valg_design_Z;
eps_lim = exp(-8.16*sin(beta_2)/Z);
D_2     = valg_design_D2;
kw      = 1;
f1      = 0.98;

if D_1m/D_2 > eps_lim
    kw = 1-((D_1m/D_2-eps_lim)/(1-eps_lim))^3;
end

slip_coeff = f1*(1-sqrt(sind(beta_2))/Z^0.70)*kw;

set(hand_calc_slip_coeff, ...
    'String',num2str(slip_coeff), ...
    'Value',slip_coeff);

%Calculate blade blockage
e_2      = valg_design_tout;
block_2  = (1-e_2*Z/(pi*D_2*sind(beta_2)))^-1;

%Calculate CU2slip
%C_U2slip_old = C_U2-(1-slip_coeff)*U_2;
C_U2slip = U_2*(slip_coeff-C_m2*block_2/(U_2*tand(beta_2)));
C_U2slip_red = C_U2slip/U_2;
set(hand_calc_CU2slip, ...
    'String',num2str(C_U2slip), ...
    'Value',C_U2slip);
set(hand_calc_CU2slip_red, ...
    'String',num2str(C_U2slip_red), ...
    'Value',C_U2slip_red);

%Calculate beta_2slip and slip_angle
beta_2slip = atand(C_m2_red/(1-C_U2slip_red));
slip_angle = beta_2-beta_2slip;

%Calculate W_2slip
W_2slip = C_m2/sind(beta_2slip);
W_2slip_red = W_2slip/U_2;
set(hand_calc_W2slip, ...
    'String',num2str(W_2slip), ...
    'Value',W_2slip);
set(hand_calc_W2slip_red, ...
    'String',num2str(W_2slip_red), ...
    'Value',W_2slip_red);

%Calculate W_U2slip
W_U2slip = C_m2/tand(beta_2slip);
W_U2slip_red = W_U2slip/U_2;
set(hand_calc_WU2slip, ...
    'String',num2str(W_U2slip), ...
    'Value',W_U2slip);
set(hand_calc_WU2slip_red, ...
    'String',num2str(W_U2slip_red), ...
    'Value',W_U2slip_red);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate absolute angles at outlet, alpha_2 and alpha_2slip
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

alpha_2     = atand(C_m2/C_U2);
alpha_2slip = atand(C_m2/C_U2slip);



%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Update outlet angles
% also setting the beta2slip values
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
set(hand_value_beta2, ...
    'String',num2str(beta_2), ...
    'Value',beta_2);
set(hand_calc_beta2, ...
    'String',num2str(valg_design_beta2))


set(hand_calc_beta2slip, ...
    'String',num2str(beta_2slip))


% set(hand_value_slip, ...
%     'String',num2str(slip_angle), ...
%     'Value',slip_angle);
set(hand_calc_slip, ...
    'String',num2str(slip_angle), ...
    'Value',slip_angle);

set(hand_calc_alpha2, ...
    'String',num2str(alpha_2), ...
    'Value',alpha_2);

set(hand_calc_alpha2slip, ...
    'String',num2str(alpha_2slip), ...
    'Value',alpha_2slip);



%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Calculate the optimal hydraulic efficiency
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
if Q>1
    a=0.5;
else
    a=1;
end

m=0.08*a*(1/Q)^0.15*(45/n_sQ)^0.06;

eta_opt=1-0.065*(1/Q)^m-0.23*(0.3-log10(n_sQ/23))^2*(1/Q)^0.05;

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% UPDATE the pump characteristics
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
set(hand_calc_eta_opt, ...
    'String',num2str(eta_opt));

% Set the calculated theoretical head
set(hand_calc_theoretical_head, ...
	'String',num2str(get(hand_calc_U2,'Value')^2/valg_design_gP));

% Set the calculated theoretical head in bar
set(hand_calc_theoretical_head_bar, ...
	'String',num2str(get(hand_calc_U2,'Value')^2*valg_design_rhoP*10^-5));

[hand_axes_charac,calc_net_head,x_max,y_max,calc_pfleiderer_slip] ... 
    = draw_charac_curves( ...
    	hand_axes_charac, ...
    	valg_design_flow, ...
    	get(hand_calc_U2,'Value'), ...
    	get(hand_calc_U1_merid,'Value'), ...
    	get(hand_calc_CU2,'Value'), ...
    	valg_design_D2, ...
    	D_1, ...
    	get(hand_value_b2,'Value'), ...
    	valg_design_beta2, ...
    	beta_1_merid, ...
    	A_1, ...
    	get(hand_calc_slip,'Value'), ...
    	param_omega, ...
    	valg_charac_friction, ...
    	valg_charac_shockloss, ...
    	valg_design_gP, ...
        valg_design_Z, ...
        valg_design_nethead ...
    );

% Set the calculated theoretical head with volume loss
set(hand_calc_theoretical_head_leakage,'String',num2str(y_max));

% Set the calculated theoretical head in bar with volume loss
set(hand_calc_theoretical_head_leakage_bar,'String',num2str(y_max*valg_design_rhoP*valg_design_gP*10^-5));

% Set the calculated slip factor based on design_flow as Pfleiderer slip    
set(hand_calc_pfleiderer,'String',num2str(calc_pfleiderer_slip));

% Set the calculated net head
set(hand_calc_net_head,'String',num2str(calc_net_head));

% Set the calculated net head in bar
set(hand_calc_net_head_bar,'String',num2str(calc_net_head*valg_design_rhoP*valg_design_gP*10^-5));




% % set(hand_calc_pfleiderer,'String',num2str(pfleiderer));

% set(hand_axes_charac, ...
%     'XLim',[0 x_max], ...
%     'YLim',[0 y_max]);


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% UPDATE the inlet velocity plot
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[hand_plot_U1_ring,  hand_text_U1_ring, ...
 hand_plot_C1_ring,  hand_text_C1_ring, ...
 hand_plot_W1_ring,  hand_text_W1_ring, ...
 hand_plot_U1_merid,  ...
 hand_plot_W1_merid, hand_text_W1_merid, ...
 hand_plot_U1_boss,   ...
 hand_plot_W1_boss,  hand_text_W1_boss] = ...
    inlet_velocity_plot_update( ...
    hand_plot_U1_ring,  hand_text_U1_ring, ...
    hand_plot_C1_ring,  hand_text_C1_ring, ...
    hand_plot_W1_ring,  hand_text_W1_ring, ...
    hand_plot_U1_merid,  ...
    hand_plot_W1_merid, hand_text_W1_merid, ...
    hand_plot_U1_boss,   ...
    hand_plot_W1_boss,  hand_text_W1_boss, ...
    U_1_ring_red,       C_m1_ring_red, ...
    U_1_merid_red,      C_m1_merid_red, ...
    U_1_boss_red,       C_m1_boss_red);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% UPDATE the outlet velocity plot
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[hand_plot_U2,hand_text_U2, ...
 hand_plot_C2,hand_text_C2, ...
 hand_plot_W2,hand_text_W2, ...
 hand_plot_CU2,hand_text_CU2, ...
 hand_plot_Cm2,hand_text_Cm2, ...
 hand_plot_C2slip,hand_text_C2slip, ...
 hand_plot_W2slip,hand_text_W2slip, ...
 hand_plot_CU2slip,hand_text_CU2slip, ...
 hand_plot_Cm2slip] = ...
    outlet_velocity_plot_update( ...
    hand_plot_U2,  hand_text_U2, ...
    hand_plot_C2,  hand_text_C2, ...
    hand_plot_W2,  hand_text_W2, ...
    hand_plot_CU2, hand_text_CU2, ...
    hand_plot_Cm2, hand_text_Cm2, ...
    hand_plot_C2slip,  hand_text_C2slip, ...
    hand_plot_W2slip,  hand_text_W2slip, ...
    hand_plot_CU2slip, hand_text_CU2slip, ...
    hand_plot_Cm2slip, ...
    U_2_red,C_m2_red,C_U2_red,C_U2slip_red);


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Calculate the nodes of the ring
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[valg_ax_nodes,old_r,old_z,new_r,new_z] = ...
    ax_design_nodes( ...
        valg_npoints_cross, ...
        valg_npoints_stream, ...
        valg_design_ax_pos, ...
        valg_design_D2,...
        valg_design_D1i, ...
        valg_design_in_z_pos );

% Update the axial cut plot

Px=get(hand_plot_ring2,'Xdata');
Py=get(hand_plot_ring2,'Ydata');

Px(end) = R_1i/R_2; % inlet point r-position
Px(1)   = R_2/R_2; % outlet point r-position
Py(end) = valg_design_in_z_pos/R_2; % inlet point z-position
Py(1)   = 0; % outlet point z-position
set(hand_plot_ring2,'XData',Px,'YData',Py); % update bezier curve
param_bezier_ax_cut_x = Px; 
param_bezier_ax_cut_y = Py;


valg_design_bezier_x=Px;
valg_design_bezier_y=Py;
[Qx,Qy] = Funct_Bezier_unplot(Px,Py,valg_npoints_cross-1);
[Qx,Qy] = even_spaces(Qx,Qy,valg_npoints_cross);

valg_ax_nodes(:,1,1) = R_2*Qx;
valg_ax_nodes(:,1,3) = R_2*Qy;



%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Calculate the streamlines
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[valg_ax_nodes(:,:,1),valg_ax_nodes(:,:,3),param_ax_view_dr, ...
  param_ax_view_dz,unit_dr,unit_dz,normal_length,param_dA_n] = ...
    ax_design_streamlines( ...
        valg_npoints_cross, ...
        valg_npoints_stream, ...
        valg_ax_nodes, ...
        valg_design_D2, ...
        valg_design_b2, ...
        get(hand_calc_D1,'Value'), ...
        valg_design_D1i, ...
        param_A1, ...
        param_A2, ...
        hand_calc_ratA ...
    );
valg_ax_nodes_red(:,:,1) = valg_ax_nodes(:,:,1)/(0.5*valg_design_D2);
valg_ax_nodes_red(:,:,3) = valg_ax_nodes(:,:,3)/(0.5*valg_design_D2);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Update axial view plot, bezier curve
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Bezier curve
x=param_bezier_ax_cut_x;
y=param_bezier_ax_cut_y;

in_z_pos = valg_design_in_z_pos;
in_z_pos_red = valg_design_in_z_pos/R_2;
x(1) = R_2_red;
x(end) = R_1i_red;
y(1) = 0;
y(end) = in_z_pos_red;

valg_design_bezier_x=x;
valg_design_bezier_y=y;
set(hand_plot_ring2,'Xdata',x,'YData',y,'Visible','on');
[Qx,Qy]=Funct_Bezier_unplot(x,y,valg_npoints_cross);
set(hand_plot_ring1,'Xdata',Qx); 
set(hand_plot_ring1,'Ydata',Qy);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Update axial view plot, the impeller vane
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
for i=1:valg_npoints_stream; 
    set(hand_plot_ax_stream_line(i), ...
        'XData',valg_ax_nodes_red(:,i,1), ...
        'YData',valg_ax_nodes_red(:,i,3), ...
        'Visible','on');
end;
for i=1:valg_npoints_cross; 
    set(hand_plot_ax_cross_line(i), ...
        'XData',valg_ax_nodes_red(i,:,1), ...
        'YData',valg_ax_nodes_red(i,:,3), ...
        'Visible','on');    
end;

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Update axial view plot, the dimensions shown on plot
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
n = valg_npoints_cross;
m = valg_npoints_stream;

arrow_start = [0 -0.01];
arrow_end = [0.5*D_2_red -0.01];
arrow_mid = 0.5*(arrow_end+arrow_start);
set(hand_plot_D2, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)]);
set(hand_fill_arrow_D2, ...
	'XData',[arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
	'YData',[arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_D2_text, ...
	'Position',[text_x text_y], ...
	'String',['D_2=',num2str(D_2),'m'], ...
	'Color','k');

arrow_start = [0 in_z_pos_red];
arrow_end = [0.5*D_1i_red in_z_pos_red];
arrow_mid = 0.5*(arrow_end+arrow_start);
set(hand_plot_D1i, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)]);
set(hand_fill_arrow_D1i, ...
	'XData',[arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
	'YData',[arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_D1i_text, ...
	'Position',[text_x text_y], ...
	'String',['D_{1i}=',num2str(D_1i),'m'], ...
	'Color','k');

arrow_start = [0 valg_ax_nodes_red(n,m,3)];
arrow_end = [valg_ax_nodes_red(n,m,1) valg_ax_nodes_red(n,m,3)];
arrow_mid = 0.5*(arrow_end+arrow_start);
set(hand_plot_D1, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)], ...
	'Color','k');
set(hand_fill_arrow_D1, ...
	'XData',[arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
	'YData',[arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_D1_text, ...
	'Position',[text_x text_y], ...
	'String',['D_1stream=',num2str(2*valg_ax_nodes(n,m,1)),'m'], ...
	'Color','k');

arrow_start = [0.40*D_1i_red 0];
arrow_end = [0.40*D_1i_red in_z_pos/R_2];
arrow_mid = 0.5*(arrow_end+arrow_start);
set(hand_plot_dz, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)], ...
	'Color','k');
set(hand_fill_arrow_dz_1, ...
	'XData',[arrow_start(1) arrow_start(1)-0.003 arrow_start(1)+0.003], ...
	'YData',[arrow_start(2) arrow_start(2)+0.008 arrow_start(2)+0.008]);
set(hand_fill_arrow_dz_2, ...
	'XData',[arrow_end(1) arrow_end(1)-0.003 arrow_end(1)+0.003], ...
	'YData',[arrow_end(2) arrow_end(2)-0.008 arrow_end(2)-0.008]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_dz_text, ...
	'Position',[text_x text_y], ...
	'String',['dz=',num2str(in_z_pos),'m']);

arrow_start = [1.05 0];
arrow_end = [1.05 valg_design_b2/R_2];
arrow_mid = 0.5*(arrow_end+arrow_start);
axis(axis);
set(hand_plot_b2, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)], ...
	'Color','k');
set(hand_fill_arrow_b2_1, ...
	'XData',[arrow_start(1) arrow_start(1)-0.003 arrow_start(1)+0.003], ...
	'YData',[arrow_start(2) arrow_start(2)+0.008 arrow_start(2)+0.008]);
set(hand_fill_arrow_b2_2, ...
	'XData',[arrow_end(1) arrow_end(1)-0.003 arrow_end(1)+0.003], ...
	'YData',[arrow_end(2) arrow_end(2)-0.008 arrow_end(2)-0.008]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_b2_text, ...
	'Position',[text_x text_y], ...
	'String',['b_2=',num2str(valg_design_b2),'m']);


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Setting the axis values automatic for the axial plot
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

% r_temp_min = [min(min(x)) min(min(valg_ax_nodes(:,:,1)))];
r_temp_max = [max(max(x)) max(max(valg_ax_nodes_red(:,:,1)))];
z_temp_min = [min(min(y)) min(min(valg_ax_nodes_red(:,:,3)))];
z_temp_max = [max(max(y)) max(max(valg_ax_nodes_red(:,:,3)))];
% r_min = min(r_temp_max);
r_max = max(r_temp_max);
z_min = min(z_temp_min);
z_max = max(z_temp_max);
r_axis_adjust = 0.1*abs(r_max);
z_axis_adjust = 0.1*abs(z_max-z_min);
set(hand_axes_maindim_axial_view, ...
	'XLim',[-0.04 r_max+r_axis_adjust], ...
    'YLim',[z_min-z_axis_adjust z_max+z_axis_adjust], ...
    'Visible','on');
