%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Design parameters
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
D_2 = valg_design_D2;
D_3 = valg_design_D3;
D_4 = valg_design_D4;
b_3 = valg_design_b3;
b_4 = valg_design_b4;
a_3 = valg_design_a3;
n   = valg_npoints_cross_diffuser;
m   = valg_npoints_stream_diffuser;
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%
% Calculate inlet values
%
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate inlet peripheral velocity component of absolute velocity, C_u3
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

C_U2slip    = get(hand_calc_CU2slip,'Value');

C_U3        = D_2*C_U2slip/D_3;
C_U3block   = C_U3;

set(hand_calc_CU3, ...
    'String',num2str(C_U3), ...
    'Value',C_U3);

set(hand_calc_CU3block, ...
    'String',num2str(C_U3block), ...
    'Value',C_U3block);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate inlet peripheral velocity component of absolute velocity, C_u3,
% without slip
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

C_U2    = get(hand_calc_CU2,'Value');

C_U3noslip        = D_2*C_U2/D_3;
C_U3noslipblock   = C_U3noslip;

set(hand_calc_CU3noslip, ...
    'String',num2str(C_U3noslip), ...
    'Value',C_U3noslip);

set(hand_calc_CU3noslipblock, ...
    'String',num2str(C_U3noslipblock), ...
    'Value',C_U3noslipblock);


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate meridional component of absolute velocity before diffuser inlet
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
Q       = valg_design_flow;

C_m3    = Q/(pi*D_3*b_3);

set(hand_calc_Cm3, ...
    'String',num2str(C_m3), ...
    'Value',C_m3);

C3      = sqrt(C_m3^2+C_U3^2);

set(hand_calc_C3, ...
    'String',num2str(C3), ...
    'Value',C3);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate diffuser throat velocity
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
Q       = valg_design_flow;
Z_Le    = valg_design_ZLe;    %Number of diffuser vanes


C_q3    = Q/(Z_Le*a_3*b_3);

set(hand_calc_CQ3, ...
    'String',num2str(C_q3), ...
    'Value',C_q3);


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate absolute flow angle before diffuser inlet
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
alpha_3 = atand(C_m3/C_U3);

set(hand_calc_alpha3, ...
    'String',num2str(alpha_3), ...
    'Value',alpha_3);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculate flow conditions after diffuser inlet (with blade blockage)
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

e_3     = valg_design_e3;       %Blade thickness at diffuser inlet

alpha_3B = valg_design_alpha3B; %Blade angle at diffuser inlet

block_3 = (1-Z_Le*e_3/(pi*D_3*sind(alpha_3B)))^-1; %Blade blockage at diffuser inlet

C_m3block = Q*block_3/(pi*D_3*b_3);    %Meridional component of flow after diffuser inlet
alpha_3block = atand(C_m3block/C_U3);   %Flow angle after diffuser inlet
C3block = sqrt(C_m3block^2+C_U3^2);

set(hand_calc_Cm3block, ...
    'String',num2str(C_m3block), ...
    'Value',C_m3block);
set(hand_calc_alpha3block, ...
    'String',num2str(alpha_3block), ...
    'Value',alpha_3block);
set(hand_calc_C3block, ...
    'String',num2str(C3block), ...
    'Value',C3block);
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% UPDATE the inlet velocity plot
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[hand_plot_C3,hand_text_C3, ...
 hand_plot_CU3,hand_text_CU3, ...
 hand_plot_Cm3,hand_text_Cm3, ...
 hand_plot_C3block,hand_text_C3block, ...
 hand_plot_CU3block,hand_text_CU3block, ...
 hand_plot_Cm3block,hand_text_Cm3block] = ...
    inlet_velocity_plot_diffuser_update( ...
    hand_plot_C3,hand_text_C3, ...
    hand_plot_CU3,hand_text_CU3, ...
    hand_plot_Cm3,hand_text_Cm3, ...
    hand_plot_C3block,hand_text_C3block, ...
    hand_plot_CU3block,hand_text_CU3block, ...
    hand_plot_Cm3block,hand_text_Cm3block, ...
    C_U3, C_U3block, ...
    C_m3, C_m3block);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Calculate the streamlines
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[valg_ax_nodes_diffuser(:,:,1),valg_ax_nodes_diffuser(:,:,3)] = ...
    ax_design_streamlines_diffuser( ...
        n, ...
        m, ...
        D_4, ...
        D_3, ...
        b_2, ...
        b_3, ...
        b_4 ...
    );
valg_ax_nodes_diffuser_red(:,:,1) = valg_ax_nodes_diffuser(:,:,1)/(0.5*valg_design_D2);
valg_ax_nodes_diffuser_red(:,:,3) = valg_ax_nodes_diffuser(:,:,3)/(0.5*valg_design_D2);


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Update axial view plot, the diffuser vane
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
for i=1:valg_npoints_stream_diffuser; 
    set(hand_plot_ax_stream_line_diffuser(i), ...
        'XData',valg_ax_nodes_diffuser_red(:,i,1), ...
        'YData',valg_ax_nodes_diffuser_red(:,i,3), ...
        'Visible','on');
end;
for i=1:valg_npoints_cross_diffuser; 
    set(hand_plot_ax_cross_line_diffuser(i), ...
        'XData',valg_ax_nodes_diffuser_red(i,:,1), ...
        'YData',valg_ax_nodes_diffuser_red(i,:,3), ...
        'Visible','on');    
end;

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Update axial view plot, the dimensions shown on plot
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
n = valg_npoints_cross_diffuser;
m = valg_npoints_stream_diffuser;
R_2 = valg_design_D2*0.5;


arrow_start = [valg_ax_nodes_diffuser_red(1,1,1)*0.95 valg_ax_nodes_diffuser_red(n,m,3)];
arrow_end = [valg_ax_nodes_diffuser_red(n,m,1) valg_ax_nodes_diffuser_red(n,m,3)];
arrow_mid = 0.5*(arrow_end+arrow_start);
set(hand_plot_D4, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)]);
set(hand_fill_arrow_D4, ...
	'XData',[arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
	'YData',[arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_D4_text, ...
	'Position',[text_x text_y], ...
	'String',['D_4=',num2str(D_4),'m'], ...
	'Color','k');

arrow_start = [valg_ax_nodes_diffuser_red(1,1,1)*0.95 valg_ax_nodes_diffuser_red(1,1,3)];
arrow_end = [valg_ax_nodes_diffuser_red(1,1,1) valg_ax_nodes_diffuser_red(1,1,3)];
arrow_mid = 0.5*(arrow_end+arrow_start);
set(hand_plot_D3, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)]);
set(hand_fill_arrow_D3, ...
	'XData',[arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
	'YData',[arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_D3_text, ...
	'Position',[text_x text_y], ...
	'String',['D_3=',num2str(D_3),'m'], ...
	'Color','k');

% arrow_start = [1 valg_ax_nodes_red(n,m,3)];
% arrow_end = [valg_ax_nodes_red(n,m,1) valg_ax_nodes_red(n,m,3)];
% arrow_mid = 0.5*(arrow_end+arrow_start);
% set(hand_plot_D1, ...
% 	'XData',[arrow_start(1) arrow_end(1)], ...
% 	'YData',[arrow_start(2) arrow_end(2)], ...
% 	'Color','k');
% set(hand_fill_arrow_D1, ...
% 	'XData',[arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
% 	'YData',[arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003]);
% text_x = arrow_mid(1);
% text_y = arrow_mid(2);
% set(hand_plot_D1_text, ...
% 	'Position',[text_x text_y], ...
% 	'String',['D_1=',num2str(2*valg_ax_nodes(n,m,1)),'m'], ...
% 	'Color','k');

arrow_start = [valg_ax_nodes_diffuser_red(1,1,1)*0.95 valg_ax_nodes_diffuser_red(1,1,3)];
arrow_end = [valg_ax_nodes_diffuser_red(1,1,1)*0.95 valg_ax_nodes_diffuser_red(1,m,3)];
arrow_mid = 0.5*(arrow_end+arrow_start);
set(hand_plot_b3, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)], ...
	'Color','k');
set(hand_fill_arrow_b3_1, ...
	'XData',[arrow_start(1) arrow_start(1)-0.003 arrow_start(1)+0.003], ...
	'YData',[arrow_start(2) arrow_start(2)+0.008 arrow_start(2)+0.008]);
set(hand_fill_arrow_b3_2, ...
	'XData',[arrow_end(1) arrow_end(1)-0.003 arrow_end(1)+0.003], ...
	'YData',[arrow_end(2) arrow_end(2)-0.008 arrow_end(2)-0.008]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_b3_text, ...
	'Position',[text_x text_y], ...
	'String',['b_3=',num2str(valg_design_b3),'m']);

arrow_start = [valg_ax_nodes_diffuser_red(n,m,1)*1.01 valg_ax_nodes_diffuser_red(n,1,3)];
arrow_end = [valg_ax_nodes_diffuser_red(n,m,1)*1.01 valg_ax_nodes_diffuser_red(n,m,3)];
arrow_mid = 0.5*(arrow_end+arrow_start);
axis(axis);
set(hand_plot_b4, ...
	'XData',[arrow_start(1) arrow_end(1)], ...
	'YData',[arrow_start(2) arrow_end(2)], ...
	'Color','k');
set(hand_fill_arrow_b4_1, ...
	'XData',[arrow_start(1) arrow_start(1)-0.003 arrow_start(1)+0.003], ...
	'YData',[arrow_start(2) arrow_start(2)+0.008 arrow_start(2)+0.008]);
set(hand_fill_arrow_b4_2, ...
	'XData',[arrow_end(1) arrow_end(1)-0.003 arrow_end(1)+0.003], ...
	'YData',[arrow_end(2) arrow_end(2)-0.008 arrow_end(2)-0.008]);
text_x = arrow_mid(1);
text_y = arrow_mid(2);
set(hand_plot_b4_text, ...
	'Position',[text_x text_y], ...
	'String',['b_4=',num2str(valg_design_b4),'m']);


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Setting the axis values automatic for the axial plot
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% % Disse brukes ved bruk av Bezierkurver, se calc_main_values
% % r_temp_min = [min(min(x)) min(min(valg_ax_nodes(:,:,1)))];
% r_temp_max = [max(max(x)) max(max(valg_ax_nodes_diffuser_red(:,:,1)))];
% z_temp_min = [min(min(y)) min(min(valg_ax_nodes_diffuser_red(:,:,3)))];
% z_temp_max = [max(max(y)) max(max(valg_ax_nodes_diffuser_red(:,:,3)))];
% r_min = min(r_temp_max);
r_max = max(max(valg_ax_nodes_diffuser_red(:,:,1)));
z_min = min(min(valg_ax_nodes_diffuser_red(:,:,3)));
z_max = max(max(valg_ax_nodes_diffuser_red(:,:,3)));
r_axis_adjust = 0.03*abs(r_max);
z_axis_adjust = 0.1*abs(z_max-z_min);
set(hand_axes_diffdesign_axial_view, ...
	'XLim',[0.96 r_max+r_axis_adjust], ...
    'YLim',[z_min-z_axis_adjust z_max+z_axis_adjust], ...
    'Visible','on', ...
    'DataAspectRatio',[1 1 1]);