%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Here are the variables/handles that need to be globally initiated
%
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% The handles of the figures
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global fig_a;       % Figure on top, with buttons
  global fig_a1;    % Main Dimensions Figure
  global fig_a2;    % Axial Design Figure
  global fig_a3;    % Control Sheet 3D Figure
  global fig_a4;    % 3D View without thickness
  global fig_a5;	% Thickness design Figure
  global fig_a6;    % Diffuser design Figure


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Chosen design values and other chosen parameters
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global valg_design_rotspeed;% Design rotational speed [rpm]
global valg_design_flow;    % Design flow of the pump [m^3/s]
global valg_design_nethead; % Net Pressure Design [N/m^2] or [Pa]

global valg_design_D1;      % Impeller eye diameter [m]
global valg_design_D2;      % Outlet Diameter [m]
global valg_design_b2;      % Outlet Height [m]
global valg_design_D1i;     % Inner streamline Diameter
global valg_design_Dn;      % Hub Diameter
global valg_design_U2;      % U_2 at outlet [m^2/s]
global valg_design_U2_red;  % U_2 at outlet [-]

%global valg_design_etaM;    % Efficiency of the pump [-]
global valg_design_gP;      % Gravitational acceleration [m/s^2]
global valg_design_rhoP;    % Fluid density [kg/m^3]

global valg_design_alpha1;  % Alpha angle at inlet
global valg_design_beta2;   % Beta angle at outlet

%global valg_design_slip;    % Outlet slip angle
global valg_design_Z;       % Total number of vanes
global valg_design_tin;     % Vane outlet thickness
global valg_design_tout;    % Vane inlet thickness

global valg_design_ax_pos;      % Where pump becomes radial!!!!!!
global valg_design_in_z_pos;    % z_in - z_out

global valg_npoints_stream;     % Number of streamline
global valg_npoints_cross;      % Number of points across streamline
global valg_npoints_stream_used;% Nodes used out of the total streamlines
global valg_npoints_cross_used; % Nodes used out of the total nodes across streamlines
global valg_ax_nodes;           % Position of nodes in axial view
global valg_ax_nodes_red;       % Position of nodes in axial view - reduced

global param_omega;			% Design rotational speed in [rad/s]

global param_A1;            % Parameter, keeping track of A_1 value
global param_A1_red;        % Reduced param_A1
global param_A2;            % Parameter, keeping track of A_2 value
global param_A2_red;        % Reduced param_A2
global param_dA_n           % Area at different points along streamline
global param_dA_n_red       % Reduced param_dA_n
global param_ax_view_dr;    % Parameter, gradient of ax_nodes
global param_ax_view_dz;    % Parameter, gradient of ax_nodes

global param_bezier_ax_cut_x;    % Start values of the
global param_bezier_ax_cut_y;    % 

global param_f;
global param_g;
global param_h;
global param_f_sum;     % Accumulated value of f
global param_g_sum;     % Accumulated value of g
global param_h_sum;     % Accumulated value of h
global param_beta;      % Beta angle for all nodes

global param_Z_drawn;   % Number of vanes drawn in [3D View]


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% 
% Handles with values of various parameters
% 
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% ----- Handles in Main dimensions -----
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

% Handles in the [Choose the design parameters] frame
global hand_value_rotspeed; % Rotational Speed
global hand_value_flow;     % Volumetric flow, Q
global hand_value_nethead;  % Net head, H

% Handles in the [Main parameters] frame
global hand_value_alpha1;   % Inlet angle
global hand_value_beta2;    % Outlet angle
%global hand_value_slip;     % Slip angle at outlet
global hand_slider_D2;      % Outlet diameter, D_2  - slider
global hand_value_D2;       % Outlet diameter, D_2
global hand_slider_D1;      % Impeller eye diameter, D_1 - slider
global hand_value_D1;       % Impeller eye diameter, D_1

global hand_value_b2;       % Outlet height, b_2
global hand_value_D1i;      % Inner streamline diameter, D_1i
global hand_value_Dn;       % Hub diameter, D_1i


global hand_value_poles;    % Number of poles
global hand_value_U2;

global hand_value_ratCm;    % Ratio of C_m2/C_m1

global hand_calc_syncrotspeed;  % Synchronous rotational speed
global hand_calc_sp_speed;  % Specific speed
global hand_calc_sp_speed_dimless; % Dimensionless specific speed

global hand_calc_D2;        % Outlet diameter
global hand_calc_D1;        % Impeller eye diameter
global hand_calc_D1m;       % Inlet mean streamline diameter

global hand_calc_NPSH_R;    % Net pressure suction head Required

global hand_calc_A2;        % Outlet area, A_2
global hand_calc_A1;        % Inlet area, A_1

global hand_calc_corrD2;    % Corrected outlet diameter

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% ----- Handles in Pump Characteristics frame -----
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global hand_calc_eta_opt;
global hand_calc_theoretical_head;
global hand_calc_theoretical_head_trad_1;
global hand_calc_theoretical_head_trad_2;
global hand_calc_theoretical_head_trad_3;
global hand_calc_theoretical_head_trad_4;
% global hand_calc_theoretical_head_trad_5;
% global hand_calc_theoretical_head_trad_6;
global hand_calc_theoretical_head_bar;
global hand_calc_theoretical_head_bar_trad_1;
global hand_calc_theoretical_head_bar_trad_2;
global hand_calc_theoretical_head_bar_trad_3;
global hand_calc_theoretical_head_bar_trad_4;
% global hand_calc_theoretical_head_bar_trad_5;
% global hand_calc_theoretical_head_bar_trad_6;
global hand_calc_net_head;
global hand_calc_net_head_trad_1;
global hand_calc_net_head_trad_2;
global hand_calc_net_head_trad_3;
global hand_calc_net_head_trad_4;
% global hand_calc_net_head_trad_5;
% global hand_calc_net_head_trad_6;
global hand_calc_net_head_bar;
global hand_calc_net_head_bar_trad_1;
global hand_calc_net_head_bar_trad_2;
global hand_calc_net_head_bar_trad_3;
global hand_calc_net_head_bar_trad_4;
% global hand_calc_net_head_bar_trad_5;
% global hand_calc_net_head_bar_trad_6;
global hand_calc_pfleiderer;
global hand_calc_pfleiderer_trad_1;
global hand_calc_pfleiderer_trad_2;
global hand_calc_pfleiderer_trad_3;
global hand_calc_pfleiderer_trad_4;
% global hand_calc_pfleiderer_trad_5;
% global hand_calc_pfleiderer_trad_6;
global hand_calc_theoretical_head_leakage;
global hand_calc_theoretical_head_leakage_trad_1;
global hand_calc_theoretical_head_leakage_trad_2;
global hand_calc_theoretical_head_leakage_trad_3;
global hand_calc_theoretical_head_leakage_trad_4;
% global hand_calc_theoretical_head_leakage_trad_5;
% global hand_calc_theoretical_head_leakage_trad_6;
global hand_calc_theoretical_head_leakage_bar;
global hand_calc_theoretical_head_leakage_bar_trad_1;
global hand_calc_theoretical_head_leakage_bar_trad_2;
global hand_calc_theoretical_head_leakage_bar_trad_3;
global hand_calc_theoretical_head_leakage_bar_trad_4;
% global hand_calc_theoretical_head_leakage_bar_trad_5;
% global hand_calc_theoretical_head_leakage_bar_trad_6;
global hand_calc_ratA;
global hand_calc_slip_coeff;
global hand_calc_slip;

global valg_characteristics_eta;
global valg_pfleiderer_slip;
global valg_charac_friction;
global valg_charac_friction_trad_1;
global valg_charac_friction_trad_2;
global valg_charac_friction_trad_3;
global valg_charac_friction_trad_4;
% global valg_charac_friction_trad_5;
% global valg_charac_friction_trad_6;
global valg_charac_shockloss;
global valg_charac_shockloss_trad_1;
global valg_charac_shockloss_trad_2;
global valg_charac_shockloss_trad_3;
global valg_charac_shockloss_trad_4;
% global valg_charac_shockloss_trad_5;
% global valg_charac_shockloss_trad_6;


global hand_slider_charac_rotspeed;
global hand_value_charac_rotspeed;
global hand_slider_charac_flow;
global hand_value_charac_flow;
global hand_slider_charac_nethead;
global hand_value_charac_nethead;
global hand_slider_charac_friction;
global hand_slider_charac_friction_trad_1;
global hand_slider_charac_friction_trad_2;
global hand_slider_charac_friction_trad_3;
global hand_slider_charac_friction_trad_4;
% global hand_slider_charac_friction_trad_5;
% global hand_slider_charac_friction_trad_6;
global hand_value_charac_friction;
global hand_value_charac_friction_trad_1;
global hand_value_charac_friction_trad_2;
global hand_value_charac_friction_trad_3;
global hand_value_charac_friction_trad_4;
% global hand_value_charac_friction_trad_5;
% global hand_value_charac_friction_trad_6;
global hand_slider_charac_shockloss;
global hand_slider_charac_shockloss_trad_1;
global hand_slider_charac_shockloss_trad_2;
global hand_slider_charac_shockloss_trad_3;
global hand_slider_charac_shockloss_trad_4;
% global hand_slider_charac_shockloss_trad_5;
% global hand_slider_charac_shockloss_trad_6;
global hand_value_charac_shockloss;
global hand_value_charac_shockloss_trad_1;
global hand_value_charac_shockloss_trad_2;
global hand_value_charac_shockloss_trad_3;
global hand_value_charac_shockloss_trad_4;
% global hand_value_charac_shockloss_trad_5;
% global hand_value_charac_shockloss_trad_6;




%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% ----- Handles in Inlet Velocities frame -----
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

% Handles in the [Inlet Velocities - reduced] frame
global hand_axes_inlet_velocity; % Inlet velocity plot

global hand_calc_beta1_ring;    % Inlet angle at ring
global hand_calc_beta1_merid;   % Inlet angle at ring
global hand_calc_beta1_boss;    % Inlet angle at ring



global hand_calc_U1_ring;        % Inlet peripheral velocity
global hand_calc_U1_ring_red;    % Inlet peripheral velocity - reduced
global hand_calc_Cm1_ring;       % Inlet meridional velocity component of absolute velocity
global hand_calc_Cm1_ring_red;   % Inlet meridional velocity component of absolute velocity - reduced
global hand_calc_W1_ring;        % Inlet relative velocity
global hand_calc_W1_ring_red;    % Inlet relative velocity - reduced

global hand_calc_U1_merid;       % Inlet peripheral velocity
global hand_calc_U1_merid_red;   % Inlet peripheral velocity - reduced
global hand_calc_Cm1_merid;      % Inlet meridional velocity component of absolute velocity
global hand_calc_Cm1_merid_red;  % Inlet meridional velocity component of absolute velocity - reduced
global hand_calc_W1_merid;       % Inlet relative velocity
global hand_calc_W1_merid_red;   % Inlet relative velocity - reduced

global hand_calc_U1_boss;        % Inlet peripheral velocity
global hand_calc_U1_boss_red;    % Inlet peripheral velocity - reduced
global hand_calc_Cm1_boss;       % Inlet meridional velocity component of absolute velocity
global hand_calc_Cm1_boss_red;   % Inlet meridional velocity component of absolute velocity - reduced
global hand_calc_W1_boss;        % Inlet relative velocity
global hand_calc_W1_boss_red;    % Inlet relative velocity - reduced

global hand_plot_U1;        % Inlet velocity diagram line U_1
global hand_plot_C1;        % Inlet velocity diagram line C_1
global hand_plot_W1;        % Inlet velocity diagram line W_1
global hand_plot_CU1;       % Inlet velocity diagram line CU_1
global hand_plot_Cm1;       % Inlet velocity diagram line C_m1
global hand_text_U1;        % Inlet velocity diagram text label U_1
global hand_text_C1;        % Inlet velocity diagram text label C_1
global hand_text_W1;        % Inlet velocity diagram text label W_1
global hand_text_CU1;       % Inlet velocity diagram text label CU_1
global hand_text_Cm1;       % Inlet velocity diagram text label C_m1

% Handles in the [Outlet Velocities - reduced] frame
global hand_axes_outlet_velocity; % Outlet velocity plot

global hand_calc_beta2;     % Outlet angle at the outer shroud
global hand_calc_beta2slip; % Outlet angle at the outer shroud with slip
global hand_calc_alpha2;    % Absolute outlet angle
global hand_calc_alpha2slip;% Absolute outlet angle with slip

global hand_calc_U2;        % Outlet peripheral velocity
global hand_calc_U2_red;    % Outlet peripheral velocity - reduced
global hand_calc_U2slip;    % Outlet peripheral velocity with slip
global hand_calc_U2slip_red;% Outlet peripheral velocity with slip - reduced
global hand_calc_Cm2;       % Outlet meridional velocity component of absolute velocity
global hand_calc_Cm2_red;   % Outlet meridional velocity component of absolute velocity - reduced
global hand_calc_Cm2slip;   % Outlet meridional velocity component of absolute velocity with slip
global hand_calc_Cm2slip_red;% Outlet meridional velocity component of absolute velocity with slip - reduced
global hand_calc_W2;        % Outlet relative velocity
global hand_calc_W2_red;    % Outlet relative velocity - reduced
global hand_calc_W2slip;    % Outlet relative velocity with slip
global hand_calc_W2slip_red;% Outlet relative velocity with slip - reduced
global hand_calc_WU2;       % Outlet peripheral velocity component of relative velocity
global hand_calc_WU2_red;   % Outlet peripheral velocity component of relative velocity - reduced
global hand_calc_WU2slip;       % Outlet peripheral velocity component of relative velocity with slip
global hand_calc_WU2slip_red;   % Outlet peripheral velocity component of relative velocity with slip - reduced
global hand_calc_CU2;       % Outlet CU_2
global hand_calc_CU2_red;   % Outlet CU_2 - reduced
global hand_calc_CU2slip;       % Outlet CU_2 with slip
global hand_calc_CU2slip_red;   % Outlet CU_2 with slip - reduced

global hand_plot_U2;        % Outlet velocity diagram line U_2
global hand_plot_C2;        % Outlet velocity diagram line C_2
global hand_plot_W2;        % Outlet velocity diagram line W_2
global hand_plot_CU2;       % Outlet velocity diagram line CU_2
global hand_plot_Cm2;       % Outlet velocity diagram line C_m2
global hand_plot_C2slip;    % Outlet velocity diagram line C_2slip
global hand_plot_W2slip;    % Outlet velocity diagram line W_2slip
global hand_plot_CU2slip;   % Outlet velocity diagram line CU_2slip
global hand_plot_Cm2slip;   % Outlet velocity diagram line C_m2slip

global hand_text_U2;        % Inlet velocity diagram text label U_2
global hand_text_C2;        % Inlet velocity diagram text label C_2
global hand_text_W2;        % Inlet velocity diagram text label W_2
global hand_text_CU2;       % Inlet velocity diagram text label CU_2
global hand_text_Cm2;       % Inlet velocity diagram text label C_m2
global hand_text_C2slip;    % Inlet velocity diagram text label C_2slip
global hand_text_W2slip;    % Inlet velocity diagram text label W_2slip
global hand_text_CU2slip;   % Inlet velocity diagram text label CU_2slip
global hand_text_Cm2slip;   % Inlet velocity diagram text label C_m2slip


% Handles in the [Axial view plot] frame
global hand_plot_maindim_axial_view;
global hand_plot_D2;
global hand_fill_arrow_D2;
global hand_plot_D2_text;
global hand_plot_D1i;
global hand_fill_arrow_D1i;
global hand_plot_D1i_text;
global hand_plot_D1;
global hand_fill_arrow_D1;
global hand_plot_D1_text;
global hand_plot_dz;
global hand_fill_arrow_dz_1;
global hand_fill_arrow_dz_2;
global hand_plot_dz_text;
global hand_plot_b2;
global hand_fill_arrow_b2_1;
global hand_fill_arrow_b2_2;
global hand_plot_b2_text;


global hand_plot_ax_stream_line;    %
global hand_plot_ax_cross_line;     %

global hand_plot_pump_up;   % 
global hand_plot_pump_down; % 
global hand_plot_pump_cl;   % Pump Axial view centerline
global hand_plot_ring1;     % 
global hand_plot_ring2;     % 


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% ----- Handles in Axial Design -----
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Axial view node handle
global hand_calc_nodes; % Axial view nodes

% Number of nodes handles
global hand_calc_npoints_cross;
global hand_calc_npoints_stream;
global hand_slider_npoints_cross_used;
global hand_calc_npoints_cross_used;
global hand_slider_npoints_stream_used;
global hand_calc_npoints_stream_used;

% Handles used in [Axial Design]
global hand_plot_axial_view;

global hand_calc_axdesign_beta2;
global hand_calc_axdesign_beta1;

global hand_plot_GH;            % GH plot - conformal representation method
global hand_plot_GH1;           % GH curve in conf. repres. meth.
global hand_plot_GH2;           % Bezier points in conf. repres. meth.
global valg_design_bezier_H;    % H in conf. repres. meth.
global valg_design_bezier_G;    % G in conf. repres. meth.
global hand_plot_GH_Beta1;      % Line showing the gradient of beta1
global hand_plot_GH_Beta2;      % Line showing the gradient of beta2
global hand_plot_GH_Beta1_text; % Text showing the value of beta1
global hand_plot_GH_Beta2_text; % Text showing the value of beta2
global polynom_spline_GH        % Spline giving the beta distribution
global param_angle_dist_ring;	% Distribution of angles from inlet to outlet

global hand_plot_ax_design_stream_line;    %
global hand_plot_ax_design_cross_line;     %


global hand_plot_rad;           % Radial view plot
global hand_plot_rad_cut_ring;  % 
global hand_plot_rad_cut_mid;
global hand_plot_rad_cut_boss;  %
global hand_plot_rad_cut_cross;

global hand_plot_velocity_load; % Velocity load plot
global hand_plot_velocity_load_ring;
global hand_plot_velocity_load_mid;
global hand_plot_velocity_load_boss;
global hand_plot_velocity_load_cross;


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% ----- Handles in 3D View -----
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Handles used in [3D View]
global hand_slider_Z;
global hand_calc_Z;
global hand_slider_Z_drawn;
global hand_calc_Z_drawn;

global hand_surf_vanes;
global hand_slider_ringboss_transp;
global hand_calc_ringboss_transp;
global hand_axes_3Dview;

global hand_slider_3Dview_x;
global hand_calc_3Dview_x;
global hand_slider_3Dview_y;
global hand_calc_3Dview_y;
global hand_slider_3Dview_z;
global hand_calc_3Dview_z;


global hand_slider_3Dview_az;
global hand_calc_3Dview_az;
global hand_slider_3Dview_el;
global hand_calc_3Dview_el;

global hand_plot_vanes;     %


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% ----- Handles in Vane Thickness -----
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global hand_surf_back_vanes

global hand_slider_inlet_suction_ellipse;
global hand_value_inlet_suction_ellipse;
global valg_inlet_suction_ellipse;

global hand_slider_inlet_suction_th_start;
global hand_value_inlet_suction_th_start;
global valg_inlet_suction_th_start;

global hand_slider_inlet_suction_th_end;
global hand_value_inlet_suction_th_end;
global valg_inlet_suction_th_end;

global hand_slider_inlet_suction_nellipse;
global hand_value_inlet_suction_nellispe;
global valg_inlet_suction_nellipse;


global hand_slider_inlet_pressure_ellipse;
global hand_value_inlet_pressure_ellipse;
global valg_inlet_pressure_ellipse;

global hand_slider_inlet_pressure_th_start;
global hand_value_inlet_pressure_th_start;
global valg_inlet_pressure_th_start;

global hand_slider_inlet_pressure_th_end;
global hand_value_inlet_pressure_th_end;
global valg_inlet_pressure_th_end;

global hand_slider_inlet_pressure_nellipse;
global hand_value_inlet_pressure_nellispe;
global valg_inlet_pressure_nellipse;


global hand_plot_thickness;
global hand_plot_f_param_suct;
global hand_plot_f_param_pres;

global hand_plot_inlet_suction_ellipse;
global hand_plot_inlet_pressure_ellipse;
global hand_plot_inlet_suction_thickness;
global hand_plot_inlet_pressure_thickness;

global hand_plot_outlet_suction_line;
global hand_plot_outlet_pressure_line;
global hand_plot_outlet_suction_thickness;
global hand_plot_outlet_pressure_thickness;

global suct_x_inlet;
global suct_y_inlet;
global suct_x_outlet;
global suct_y_outlet;
global pres_x_inlet;
global pres_y_inlet;
global pres_x_outlet;
global pres_y_outlet;

global inlet_suct_last_node;
global inlet_pres_last_node;

global impeller_thickness; % linear thickness change from outlet to inlet, based on the streamline length according to param_f_sum

global suction_side_f_param;
global suction_side_thickness; 
global pressure_side_f_param;
global pressure_side_thickness;


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%
% ----- Values in Diffuser design -----
%
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Chosen design values and other chosen parameters
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global valg_design_D3;  % Diffuser inlet diameter
global valg_design_b3;  % Diffuser inlet height
global valg_design_a3;  % Diffuser throat width
global valg_design_alpha3B; %Vane angle at inlet
global valg_design_D4;  % Diffuser outlet diameter
global valg_design_b4;  %Diffuser outlet height
global valg_design_ZLe; % Number of diffuser vanes
global valg_design_e3;  % Vane thickness at inlet
global valg_npoints_cross_diffuser; %Number of nodes across streamlines
global valg_npoints_stream_diffuser; %Number of streamlines
global valg_ax_nodes_diffuser;
global valg_ax_nodes_diffuser_red;

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Handles in diffuser design
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

global hand_value_D3;
global hand_slider_D3;
global hand_value_b3;
global hand_slider_b3;
global hand_value_a3;
global hand_slider_a3;
global hand_value_alpha3B;
global hand_slider_alpha3B;
global hand_value_D4;
global hand_slider_D4;
global hand_value_b4;
global hand_slider_b4;


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Calculated values in diffuser design
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global hand_calc_CU3;       % Peripheral component of absolute inlet velocity
global hand_calc_CU3block;
global hand_calc_CU3noslip;       % Peripheral component of absolute inlet velocity without slip
global hand_calc_CU3noslipblock;
global hand_calc_Cm3;       % Meridional component of absolute inlet velocity
global hand_calc_Cm3block;
global hand_calc_C3;        % Aboslute velocity
global hand_calc_C3block;
global hand_calc_CQ3; 
global hand_calc_alpha3;    % Absolute flow angle at inlet
global hand_calc_alpha3block;

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Other parameters
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%global param_A1_diffuser;            % Parameter, keeping track of A_1_diff value
%global param_A2_diffuser;            % Parameter, keeping track of A_2_diff value
%global param_db_n;

% % Handles in the [Axial view plot] frame
global hand_plot_diffdesign_axial_view;
global hand_plot_D4;
global hand_fill_arrow_D4;
global hand_plot_D4_text;
global hand_plot_D3;
global hand_fill_arrow_D3;
global hand_plot_D3_text;

global hand_plot_b3;
global hand_fill_arrow_b3_1;
global hand_fill_arrow_b3_2;
global hand_plot_b3_text;
global hand_plot_b4;
global hand_fill_arrow_b4_1;
global hand_fill_arrow_b4_2;
global hand_plot_b4_text;
% 
% 
global hand_plot_ax_stream_line_diffuser;    %
global hand_plot_ax_cross_line_diffuser;     %
% 
% global hand_plot_b2;        % 
% global hand_plot_pump_up;   % 
% global hand_plot_pump_down; % 
% global hand_plot_pump_cl;   % Pump Axial view centerline
% global hand_plot_ring1;     % 
% global hand_plot_ring2;     % 



%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Handles of various calculations
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc



%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Handles of the various plots
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% global hand_plot_inlet;
% global hand_plot_outlet;


global valg_design_bezier_x;    % 
global valg_design_bezier_y;    % 



global valg_design_AZ;      %
global valg_design_EL;      %
global hand_value_AZ;       %
global hand_value_EL;       %
global hand_value_Zvis;     %
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Ellipse - Leading edge of vane, suction side
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global hand_value_ellipse_suge_abrat;   %
global hand_value_ellipse_suge_theta1;  %
global hand_value_ellipse_suge_theta2;  %
global valg_design_ellipse_suge_abrat;  % Ellipse shape a/b
global valg_design_ellipse_suge_theta1; % Theta start at ellipse
global valg_design_ellipse_suge_theta2; % Theta end at ellipse
global hand_plot_suge_le1;  %
global hand_plot_suge_le2;  %

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Ellipse - Leading edge of edge vane, pressure side
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global hand_value_ellipse_tr_abrat;     %
global hand_value_ellipse_tr_theta1;    %
global hand_value_ellipse_tr_theta2;    %
global valg_design_ellipse_tr_abrat;    %Ellipse shape a/b
global valg_design_ellipse_tr_theta1;   %Theta start at ellipse
global valg_design_ellipse_tr_theta2;   %Theta end at ellipse
global hand_plot_tr_le1;    %
global hand_plot_tr_le2;    %
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Colors of the GUI
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
global backcolor;   %background color in the program
global buttcolor;   %button color in the program
global linecolor;   %line color of the inner frames in the program
global okcolor;     %
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

global hand_wait;