%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%
%   G-H plot
%   Distribution of beta from inlet to outlet
%
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

b = uipanel('Parent',fig_a2, ...
	'Units','normalized', ...
	'BackgroundColor',buttcolor, ...
    'ForegroundColor',linecolor, ...
	'FontWeight','bold', ...
    'Title','Conformal representation method', ...
	'Position',[x1 y1 dx1 dy1]);

hand_plot_GH = subplot(3,6,[13 14 15]);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Find the initial Bezier points
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

% Calculate Bezier points - Outlet
x(1)=0; y(1)=0;
beta2 = valg_design_beta2;
dx=0.5*cosd(beta2); x(2)=x(1)+dx;
dy=0.5*sind(beta2); y(2)=y(1)+dy;

% Calculate Bezier points - Inlet
x(4)=1; y(4)=1;  
beta1_ring =str2num(get(hand_calc_beta1_ring,'String'));
beta1_merid=str2num(get(hand_calc_beta1_merid,'String'));
beta1_boss =str2num(get(hand_calc_beta1_boss,'String'));

dx=0.5*cosd(beta1_ring); x(3)=x(4)-dx;
dy=0.5*sind(beta1_ring); y(3)=y(4)-dy;


%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Find the points from the Bezier points
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

valg_design_bezier_H=x;
valg_design_bezier_G=y;

[Qx_temp,Qy_temp]=Funct_Bezier_unplot(x,y,valg_npoints_cross-1);
[Qx,Qy] = even_spaces(Qx_temp,Qy_temp,valg_npoints_cross);

polynom_spline_GH = spline(Qx,Qy);

[param_angle_dist_ring] = get_spline_angle(polynom_spline_GH);
out_angle = param_angle_dist_ring(1);
in_angle  = param_angle_dist_ring(end);

hand_plot_GH1=plot(Qx,Qy,'r-','LineWidth',2); hold on;
% hand_plot_GH1_merid=plot(Qx_merid,Qy_merid,'g');
% hand_plot_GH1_boss=plot(Qx_boss,Qy_boss,'g');
hand_plot_GH2=plot(x,y,'k-o'); 
set(hand_plot_GH2,'ButtonDownFcn','change_line_GH(hand_plot_GH2,''axy'');');

xlabel('Normalized G [-]'); ylabel('Normalized H [-]');
legend('\beta distribution along ring streamline','Bezier points','Location','NorthWest')

Pos_margin = get(hand_plot_GH,'TightInset');
set(hand_plot_GH, ...
    'Units','normalized', ...
    'Position',[x1+Pos_margin(1) y1+Pos_margin(2) dx1-0.03-Pos_margin(1)-Pos_margin(3) dy1-0.03-Pos_margin(2)-Pos_margin(4)], ...
    'DataAspectRatio',[1 1 1], ...
    'Clipping','on', ...
    'XDir','reverse', ...
    'YDir','reverse', ...
    'XLim',[-0.3 1.3], ...
    'YLim',[-0.3 1.3]);

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Set the beta values on the GH-plot
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

% Show Beta2 on GH-plot

dx=-0.1*cosd(out_angle);
dy=-0.1*sind(out_angle);
hand_plot_GH_Beta2=line([Qx(1) Qx(1)+dx],[Qy(1) Qy(1)+dy]);
hand_plot_GH_Beta2_text=text(Qx(1)+dx,Qy(1)+dy, ...
    ['\beta_{2,ring} = ',num2str(out_angle,3),'^o']);
set(hand_plot_GH_Beta2_text,'HorizontalAlignment','left', ...
    'VerticalAlignment','bottom')

% Show Beta1 on GH-plot
ant=length(Qx);
dx=0.1*cosd(in_angle);
dy=0.1*sind(in_angle);
hand_plot_GH_Beta1=line([Qx(end) Qx(end)+dx],[Qy(end) Qy(end)+dy]);
hand_plot_GH_Beta1_text=text(Qx(end)+dx,Qy(end)+dy, ...
    ['\beta_{1.ring} = ',num2str(in_angle,3),'^o']);
set(hand_plot_GH_Beta1_text,'HorizontalAlignment','right', ...
    'VerticalAlignment','top')

%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
% Update the values for the beta1 and beta2 in the angles frame
%cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
set(hand_calc_axdesign_beta2,'String',num2str(out_angle));
set(hand_calc_axdesign_beta1,'String',num2str(in_angle));