%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Plot - Pump axial view
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
b = uipanel('Parent',fig_a1, ...
	'Units','normalized', ...
	'BackgroundColor',buttcolor, ...
    'ForegroundColor',linecolor, ...
	'FontWeight','bold', ...
    'Title','Axial view of the impeller ', ...
	'Position',[0.32 0.01 0.67 0.56]);

hand_axes_maindim_axial_view = subplot(3,3,8:9);
set(hand_axes_maindim_axial_view,'NextPlot','add','Visible','off')

Pos_margin = get(hand_axes_maindim_axial_view,'TightInset');
set(hand_axes_maindim_axial_view,'Units','normalized', ...
    'DataAspectRatio',[1 1 1], ...
    'Position',[x1+Pos_margin(1) y1+Pos_margin(2) 0.97-x1-Pos_margin(1) dy1-Pos_margin(4)], ...
    'Clipping','on', ...
    'NextPlot','add', ...
    'Box','on');
xlabel('Radius, R [-]'); ylabel('Z-axis, Z [-]'); 

% hand_plot_pump_up = line([0 1],[0 0]);
% set(hand_plot_pump_up,'Color','r','LineStyle',':');
% hand_plot_pump_down = line([0 1],[0 0]); 
% set(hand_plot_pump_down,'Color','r','LineStyle',':');

n = valg_npoints_cross;
m = valg_npoints_stream;

D_2 = valg_design_D2;
R_2 = 0.5*D_2;
D_2_red = D_2/R_2; % Should be = 2s
R_2_red = 0.5*D_2_red; % Defined as 1
D_1i = valg_design_D1i;
R_1i = 0.5*D_1i;
D_1i_red = D_1i/R_2;
R_1i_red = 0.5*D_1i_red;
in_z_pos = valg_design_in_z_pos;
in_z_pos_red = in_z_pos/R_2;

% Calculate the nodes of the ring
[valg_ax_nodes,old_r,old_z,new_r,new_z] = ...
    ax_design_nodes( ...
        n, ...
        m, ...
        valg_design_ax_pos, ...
        D_2,...
        D_1i, ...
        in_z_pos ...
    );

% Calculate the streamlines
[valg_ax_nodes(:,:,1),valg_ax_nodes(:,:,3),param_ax_view_dr, ...
  param_ax_view_dz,unit_dr,unit_dz,normal_length,param_dA_n] = ...
    ax_design_streamlines( ...
        n, ...
        m, ...
        valg_ax_nodes, ...
        D_2, ...
        valg_design_b2, ...
        get(hand_calc_D1,'Value'), ...
        D_1i, ...
        param_A1, ...
        param_A2, ...
        hand_calc_ratA ...
    );
    
    
valg_ax_nodes_red(:,:,1) = valg_ax_nodes(:,:,1)/(0.5*valg_design_D2);
valg_ax_nodes_red(:,:,3) = valg_ax_nodes(:,:,3)/(0.5*valg_design_D2);


% Plot the streamlines
[hand_plot_ax_cross_line,hand_plot_ax_stream_line] =  ...
    plot_rz_plane_ax_design( ...
        hand_axes_maindim_axial_view, ...
        n, ...
        m, ...
        valg_ax_nodes_red(:,:,1), ...
        valg_ax_nodes_red(:,:,3), ...
        D_2 ...
    );


% Update the rz-plane plot
[hand_plot_ax_cross_line, ...
  hand_plot_ax_stream_line] = ...
    update_rz_plot( ...
        hand_plot_ax_cross_line, ...
        hand_plot_ax_stream_line, ...
        n, ...
        m ...
    );

param_bezier_ax_cut_x = linspace(R_2_red,R_1i_red,4);
param_bezier_ax_cut_y = linspace(0,in_z_pos_red,4);
param_bezier_ax_cut_y(2) = 0;
param_bezier_ax_cut_y(3) = 0;
x = param_bezier_ax_cut_x;
y = param_bezier_ax_cut_y;


%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Setting the arrows giving the actual dimension of
% 	the impeller
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

arrow_start = [0 -0.01];
arrow_end = [0.5*D_2_red -0.01];
arrow_mid = 0.5*(arrow_end+arrow_start);
hand_plot_D2 = line([arrow_start(1) arrow_end(1)], [arrow_start(2) arrow_end(2)],'Color','k');
hand_fill_arrow_D2 = fill([arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
     				      [arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003], ...
                          'k');
text_x = arrow_mid(1);
text_y = arrow_mid(2);
hand_plot_D2_text = text(text_x,text_y,['D_2=',num2str(D_2),'m'], ...
	'Color','k','BackgroundColor','w','Margin',1, ...
	'VerticalAlignment','bottom','HorizontalAlignment','center');

arrow_start = [0 in_z_pos_red];
arrow_end = [0.5*D_1i_red in_z_pos_red];
arrow_mid = 0.5*(arrow_end+arrow_start);
hand_plot_D1i = line([arrow_start(1) arrow_end(1)], [arrow_start(2) arrow_end(2)],'Color','k');
hand_fill_arrow_D1i = fill([arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
     						[arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003], ...
     						'k');
text_x = arrow_mid(1);
text_y = arrow_mid(2);
hand_plot_D1i_text = text(text_x,text_y,['D_{1i}=',num2str(D_1i),'m'], ...
	'Color','k','BackgroundColor','w','Margin',1, ...
	'VerticalAlignment','top','HorizontalAlignment','center');

arrow_start = [0 0.1+valg_ax_nodes_red(n,m,3)];
arrow_end = [valg_ax_nodes_red(n,m,1) 0.1+valg_ax_nodes_red(n,m,3)];
arrow_mid = 0.5*(arrow_end+arrow_start);
hand_plot_D1 = line([arrow_start(1) arrow_end(1)], [arrow_start(2) arrow_end(2)],'Color','k');
hand_fill_arrow_D1 = fill([arrow_end(1) arrow_end(1)-0.008 arrow_end(1)-0.008], ...
     			          [arrow_end(2) arrow_end(2)-0.003 arrow_end(2)+0.003], ...
     					  'k');
text_x = arrow_mid(1);
text_y = arrow_mid(2);
hand_plot_D1_text = text(text_x,text_y,['D_1stream=',num2str(valg_ax_nodes(n,m,1)),'m'], ...
	'Color','k','BackgroundColor','w','Margin',1, ...
	'VerticalAlignment','top','HorizontalAlignment','center');

arrow_start = [0.25*D_1i_red 0];
arrow_end = [0.25*D_1i_red in_z_pos/R_2];
arrow_mid = 0.5*(arrow_end+arrow_start);
hand_plot_dz = line([arrow_start(1) arrow_end(1)], [arrow_start(2) arrow_end(2)],'Color','k');
hand_fill_arrow_dz_1 = fill([arrow_start(1) arrow_start(1)-0.003 arrow_start(1)+0.003], ...
     			            [arrow_start(2) arrow_start(2)+0.008 arrow_start(2)+0.008], ...
     					    'k');
hand_fill_arrow_dz_2 = fill([arrow_end(1) arrow_end(1)-0.003 arrow_end(1)+0.003], ...
     			            [arrow_end(2) arrow_end(2)-0.008 arrow_end(2)-0.008], ...
     					    'k');
text_x = arrow_mid(1);
text_y = arrow_mid(2);
hand_plot_dz_text = text(text_x,text_y,['dz=',num2str(in_z_pos),'m'], ...
	'Color','k','BackgroundColor','w','Margin',1, ...
	'VerticalAlignment','middle','HorizontalAlignment','center');

arrow_start = [1.05 0];
arrow_end = [1.05 valg_design_b2/R_2];
arrow_mid = 0.5*(arrow_end+arrow_start);
hand_plot_b2 = line([arrow_start(1) arrow_end(1)], [arrow_start(2) arrow_end(2)],'Color','k');
hand_fill_arrow_b2_1 = fill([arrow_start(1) arrow_start(1)-0.003 arrow_start(1)+0.003], ...
     			            [arrow_start(2) arrow_start(2)+0.008 arrow_start(2)+0.008], ...
     					  'k');
hand_fill_arrow_b2_2 = fill([arrow_end(1) arrow_end(1)-0.003 arrow_end(1)+0.003], ...
     			            [arrow_end(2) arrow_end(2)-0.008 arrow_end(2)-0.008], ...
     					  'k');
text_x = arrow_mid(1);
text_y = arrow_mid(2);
hand_plot_b2_text = text(text_x,text_y,['b_2=',num2str(valg_design_b2),'m'], ...
	'Color','k','BackgroundColor','w','Margin',1, ...
	'VerticalAlignment','middle','HorizontalAlignment','center');



hand_plot_ring2=plot(hand_axes_maindim_axial_view,x,y,'g-o');
valg_design_bezier_x=x; 
valg_design_bezier_y=y;
set(hand_plot_ring2, ...
	'ButtonDownFcn','change_line(hand_plot_ring2,''axy'');', ...
	'Visible','off');
