%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%
%   Vane thickness at inlet, control of the ellipse
%
%	Frame for choice
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

b = uipanel('Parent',fig_a5, ...
	'Units','normalized', ...
	'BackgroundColor',buttcolor, ...
    'ForegroundColor',linecolor, ...
	'FontWeight','bold', ...
    'Title','Vane inlet, ellipse control', ...
	'Position',[x1 y1 dx1 dy1]);

n = valg_npoints_cross;
m = valg_npoints_stream;

hand_axes_inlet_thickness = subplot(3,2,3);
hold on;

streamline_lengths = param_f_sum(end,:);
s_temp = size(param_f_sum);
str_temp = zeros(s_temp(1),1);
hand_plot_inlet_streamline = plot(param_f_sum(:,1),str_temp,'r-x');

% suction_side_f_param    = [];
% suction_side_thickness  = [];
% pressure_side_f_param   = [];
% pressure_side_thickness = [];


%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the inlet suction side ellipse
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[a_suc,b_suc]  = find_ellipse_ab( ...
	valg_inlet_suction_ellipse, ...
	valg_design_tin, ...
	valg_design_tout, ...
	streamline_lengths);

suct_x_inlet = zeros(valg_inlet_suction_nellipse,m);
suct_y_inlet = zeros(valg_inlet_suction_nellipse,m);

for i=1:m
	[suct_x_inlet(:,i),suct_y_inlet(:,i)] = ellipse( ...
		a_suc, ...
		b_suc(i), ...
		param_f_sum(end,i)-a_suc, ...
		0, ...
		180+valg_inlet_suction_th_start, ...
		180+valg_inlet_suction_th_end, ...
		valg_inlet_suction_nellipse);
end
suct_y_inlet = -suct_y_inlet;

hand_plot_inlet_suction_ellipse  = plot(suct_x_inlet(:,1),suct_y_inlet(:,1),'b-x');

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the inlet pressure side ellipse
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[a_pres,b_pres]  = find_ellipse_ab( ...
	valg_inlet_pressure_ellipse, ...
	valg_design_tin, ...
	valg_design_tout, ...
	streamline_lengths);

pres_x_inlet = zeros(valg_inlet_pressure_nellipse,m);
pres_y_inlet = zeros(valg_inlet_pressure_nellipse,m);


for i=1:m
	[pres_x_inlet(:,i),pres_y_inlet(:,i)] = ellipse( ...
		a_pres, ...
		b_pres(i), ...
		param_f_sum(end,i)-a_pres, ...
		0, ...
		180+valg_inlet_pressure_th_start, ...
		180+valg_inlet_pressure_th_end, ...
		valg_inlet_pressure_nellipse);
end


hand_plot_inlet_pressure_ellipse = plot(pres_x_inlet(:,1),pres_y_inlet(:,1),'b-x');

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the thickness of the vane at the inlet
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
tin  = valg_design_tin;
tout = valg_design_tout;
n = valg_npoints_cross;
m = valg_npoints_stream;
impeller_thickness = zeros(n,m);
param_f_sum_normalized = zeros(size(param_f_sum));

for i=1:m
	param_f_sum_normalized(:,i) = param_f_sum(:,i)/param_f_sum(end,i);
	impeller_thickness(:,i) = tout+(tin-tout)*param_f_sum_normalized(:,i);
end

inlet_suct_last_node = zeros(1,m);
inlet_pres_last_node = zeros(1,m);

% counter
% the variable counter is only used for security
% so if there is an error in the while loop does not
% without a limit

for j=1:m
	i=n;
	counter=1;
	while param_f_sum(i,1)>suct_x_inlet(1) && counter<1000
		i=i-1;		
		inlet_suct_last_node(j) = i;
		counter=counter+1;
	end
end
hand_plot_inlet_suction_thickness  = plot( ...
	[param_f_sum(1:inlet_suct_last_node,1); suct_x_inlet(1)], ...
	[0.5*impeller_thickness(1:inlet_suct_last_node,1);suct_y_inlet(1)], ...
	'b');

for j=1:m
	i=n;
	counter=1;
	while param_f_sum(i,1)>pres_x_inlet(1) && counter<1000
		i=i-1;
		inlet_pres_last_node(j) = i;
		counter=counter+1;
	end
end
hand_plot_inlet_pressure_thickness = plot( ...
	[param_f_sum(1:inlet_pres_last_node,1); pres_x_inlet(1)], ...
	[-0.5*impeller_thickness(1:inlet_pres_last_node,1); pres_y_inlet(1)], ...
	'b');


%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Set the axis limits and properties
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
Pos_margin = get(hand_axes_inlet_thickness,'TightInset');
xmax = param_f_sum(end,1)+0.01;
xmin = param_f_sum(end,1)-0.03;
set(hand_axes_inlet_thickness, ...
	'Units','Normalized', ...
	'Box','on', ...
    'Position',[x1+0.02+Pos_margin(1) y1+0.02+Pos_margin(2) dx1-0.04-Pos_margin(1)-Pos_margin(3) dy1-0.04-Pos_margin(2)-Pos_margin(4)], ...
	'XLim',[xmin xmax], ...
	'YLim',[-1.1*valg_design_tin 1.1*valg_design_tin], ...
	'XDir','reverse' ...
	);