%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%
%   Vane thickness at outlet, control of the outlet
%
%	Frame for choice
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

b = uipanel('Parent',fig_a5, ...
	'Units','normalized', ...
	'BackgroundColor',buttcolor, ...
    'ForegroundColor',linecolor, ...
	'FontWeight','bold', ...
    'Title','Vane outlet, detail', ...
	'Position',[x1 y1 dx1 dy1]);
	
hand_axes_outlet_thickness = subplot(3,2,4);
hold on;

streamline_lengths = param_f_sum(end,:);
s_temp = size(param_f_sum);
str_temp = zeros(s_temp(1),1);
hand_plot_outlet_streamline = plot(param_f_sum(:,1),str_temp,'r-x');

beta2 = valg_design_beta2;
tin  = valg_design_tin;
tout = valg_design_tout;
n = valg_npoints_cross;
m = valg_npoints_stream;
npoints_line = 2;

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the outlet suction side
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
suct_x_outlet = zeros(npoints_line,m);
suct_y_outlet = zeros(npoints_line,m);

for i=1:m
	suct_y_outlet(:,i) = linspace(0,0.5*tout,npoints_line);
	suct_x_outlet(:,i) = -suct_y_outlet(:,i)/tand(beta2);
end

hand_plot_outlet_suction_line = plot(suct_x_outlet(:,1),suct_y_outlet(:,1),'b-x');


%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the outlet pressure side
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
pres_x_outlet = zeros(npoints_line,m);
pres_y_outlet = zeros(npoints_line,m);

for i=1:m
	pres_y_outlet(:,i) = linspace(0,-0.5*tout,npoints_line);
	pres_x_outlet(:,i) = -pres_y_outlet(:,i)/tand(beta2);
end

hand_plot_outlet_pressure_line = plot(pres_x_outlet(:,1),pres_y_outlet(:,1),'b-x');


%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the thickness of the vane at the outlet
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
impeller_thickness = zeros(n,m);
param_f_sum_normalized = zeros(size(param_f_sum));

for i=1:m
	param_f_sum_normalized(:,i) = param_f_sum(:,i)/param_f_sum(end,i);
	impeller_thickness(:,i) = tout+(tin-tout)*param_f_sum_normalized(:,i);
end


hand_plot_outlet_suction_thickness  = plot( ...
	[suct_x_outlet(end,1); param_f_sum(2:end,1)], ...
	[suct_y_outlet(end,1); 0.5*impeller_thickness(2:end,1)], ...
	'b');

hand_plot_outlet_pressure_thickness  = plot( ...
	[pres_x_outlet(end,1); param_f_sum(2:end,1)], ...
	[pres_y_outlet(end,1); -0.5*impeller_thickness(2:end,1)], ...
	'b');


%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Set the axis limits and properties
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
Pos_margin = get(hand_axes_outlet_thickness,'TightInset');
xmax = 0.03;
xmin = -0.01;
set(hand_axes_outlet_thickness, ...
	'Units','Normalized', ...
	'Box','on', ...
    'Position',[x1+0.02+Pos_margin(1) y1+0.02+Pos_margin(2) dx1-0.04-Pos_margin(1)-Pos_margin(3) dy1-0.04-Pos_margin(2)-Pos_margin(4)], ...
	'XLim',[xmin xmax], ...
	'YLim',[-1.1*valg_design_tin 1.1*valg_design_tin], ...
	'XDir','reverse' ...
	);	