%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%
%   Vane thickness along the total length, 
%   inlet determined by an ellipse
%   outlet is cut to fit the circumference of the outlet
%
%	Frame for choice
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

b = uipanel('Parent',fig_a5, ...
	'Units','normalized', ...
	'BackgroundColor',buttcolor, ...
    'ForegroundColor',linecolor, ...
	'FontWeight','bold', ...
    'Title','Vane thickness, total length', ...
	'Position',[x1 y1 dx1 dy1]);

hand_axes_thickness_vane = subplot(2,3,[1 2]);

xlabel('Length of the streamline at ring [m]')
ylabel('Thickness of the vanes [m]');

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Set the axis limits and properties
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
Pos_margin = get(hand_axes_thickness_vane,'TightInset');
set(hand_axes_thickness_vane, ...
	'Units','Normalized', ...
	'Box','on', ...
	'NextPlot','add', ...
    'Position',[x1+0.02+Pos_margin(1) y1+0.02+Pos_margin(2) dx1-0.04-Pos_margin(1)-Pos_margin(3) dy1-0.04-Pos_margin(2)-Pos_margin(4)], ...
	'XDir','reverse' ...
	);

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Set the parameters for plotting vane
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

suction_side_f_param    = [suct_x_outlet; param_f_sum(2:inlet_suct_last_node,:);             suct_x_inlet];
suction_side_thickness  = [suct_y_outlet; 0.5*impeller_thickness(2:inlet_suct_last_node,:);  suct_y_inlet];
pressure_side_f_param   = [pres_x_outlet; param_f_sum(2:inlet_pres_last_node,:);             pres_x_inlet];
pressure_side_thickness = [pres_y_outlet; -0.5*impeller_thickness(2:inlet_pres_last_node,:); pres_y_inlet];

param_plot_f_param   = [suction_side_f_param(:,1),  pressure_side_f_param(:,1)  ];
param_plot_thickness = [suction_side_thickness(:,1) pressure_side_thickness(:,1)];

suct_plot_f_param =  0.5*ones(length(suction_side_f_param(:,1)),1) *max(valg_design_tin,valg_design_tout);
pres_plot_f_param = -0.5*ones(length(pressure_side_f_param(:,1)),1)*max(valg_design_tin,valg_design_tout);


hand_plot_thickness = plot(...
	param_plot_f_param, ...
	param_plot_thickness, ...
	'-ob');

hand_plot_f_param_suct = plot(...
	suction_side_f_param(:,1), ...
	suct_plot_f_param, ...
	'-or');

hand_plot_f_param_pres = plot(...
	pressure_side_f_param(:,1), ...
	pres_plot_f_param, ...
	'-or');


