function [] = thickness_inlet_control_update();
declare_global_variables();

streamline_lengths = param_f_sum(end,:);
m = valg_npoints_stream;

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the inlet suction side ellipse
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[a_suc,b_suc]  = find_ellipse_ab( ...
	valg_inlet_suction_ellipse, ...
	valg_design_tin, ...
	valg_design_tout, ...
	streamline_lengths);

suct_x_inlet = zeros(valg_inlet_suction_nellipse,m);
suct_y_inlet = zeros(valg_inlet_suction_nellipse,m);

for i=1:m
	[suct_x_inlet(:,i),suct_y_inlet(:,i)] = ellipse( ...
		a_suc, ...
		b_suc(i), ...
		param_f_sum(end,i)-a_suc, ...
		0, ...
		180+valg_inlet_suction_th_start, ...
		180+valg_inlet_suction_th_end, ...
		valg_inlet_suction_nellipse);
end
suct_y_inlet = -suct_y_inlet;

set(hand_plot_inlet_suction_ellipse, ...
	'XData',suct_x_inlet(:,1), ...
	'YData',suct_y_inlet(:,1));

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the inlet pressure side ellipse
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
[a_pres,b_pres]  = find_ellipse_ab( ...
	valg_inlet_pressure_ellipse, ...
	valg_design_tin, ...
	valg_design_tout, ...
	streamline_lengths);

pres_x_inlet = zeros(valg_inlet_pressure_nellipse,m);
pres_y_inlet = zeros(valg_inlet_pressure_nellipse,m);


for i=1:m
	[pres_x_inlet(:,i),pres_y_inlet(:,i)] = ellipse( ...
		a_pres, ...
		b_pres(i), ...
		param_f_sum(end,i)-a_pres, ...
		0, ...
		180+valg_inlet_pressure_th_start, ...
		180+valg_inlet_pressure_th_end, ...
		valg_inlet_pressure_nellipse);
end

set(hand_plot_inlet_pressure_ellipse, ...
	'XData',pres_x_inlet(:,1), ...
	'YData',pres_y_inlet(:,1));

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Find the thickness of the vane at the inlet
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
tin  = valg_design_tin;
tout = valg_design_tout;
n = valg_npoints_cross;
m = valg_npoints_stream;
impeller_thickness = zeros(n,m);
param_f_sum_normalized = zeros(size(param_f_sum));

for i=1:m
	param_f_sum_normalized(:,i) = param_f_sum(:,i)/param_f_sum(end,i);
	impeller_thickness(:,i) = tout+(tin-tout)*param_f_sum_normalized(:,i);
end

%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Update the leading edge plot
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

inlet_suct_last_node = zeros(1,m);
inlet_pres_last_node = zeros(1,m);

for j=1:m
	i=n;
	counter=1;
	while param_f_sum(i,1)>suct_x_inlet(1) && counter<1000
		i=i-1;		
		inlet_suct_last_node(j) = i;
		counter=counter+1;
	end
end
set(hand_plot_inlet_suction_thickness, ...
	'XData',[param_f_sum(1:inlet_suct_last_node,1); suct_x_inlet(:,1)], ...
	'YData',[0.5*impeller_thickness(1:inlet_suct_last_node,1);suct_y_inlet(:,1)]);



for j=1:m
	i=n;
	counter=1;
	while param_f_sum(i,1)>pres_x_inlet(1) && counter<1000
		i=i-1;
		inlet_pres_last_node(j) = i;
		counter=counter+1;
	end
end
set(hand_plot_inlet_pressure_thickness, ...
	'XData',[param_f_sum(1:inlet_pres_last_node,1); pres_x_inlet(:,1)], ...
	'YData',[-0.5*impeller_thickness(1:inlet_pres_last_node,1);pres_y_inlet(:,1)]);


%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Update the 3D surface plot
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
r = valg_ax_nodes(:,:,1);
x = valg_ax_nodes(:,:,1).*sind(valg_ax_nodes(:,:,2));
y = valg_ax_nodes(:,:,1).*cosd(valg_ax_nodes(:,:,2));
z = valg_ax_nodes(:,:,3);

suction_side_f_param    = [suct_x_outlet; param_f_sum(2:inlet_suct_last_node,:);             suct_x_inlet];
suction_side_thickness  = [suct_y_outlet; 0.5*impeller_thickness(2:inlet_suct_last_node,:);  suct_y_inlet];
pressure_side_f_param   = [pres_x_outlet; param_f_sum(2:inlet_pres_last_node,:);             pres_x_inlet];
pressure_side_thickness = [pres_y_outlet; -0.5*impeller_thickness(2:inlet_pres_last_node,:); pres_y_inlet];


param_g_sum_suction  = zeros(size(suction_side_f_param));
param_h_sum_suction  = zeros(size(suction_side_f_param));
param_g_sum_pressure = zeros(size(pressure_side_f_param));
param_h_sum_pressure = zeros(size(pressure_side_f_param));


[n_suct,m_suct] = size(suction_side_f_param);
[n_pres,m_pres] = size(pressure_side_f_param);
suction_nodes   = zeros(n_suct,m_suct,3);
pressure_nodes  = zeros(n_pres,m_pres,3);

suction_nodes_pol  = zeros(n_suct,m_suct,3);
pressure_nodes_pol = zeros(n_pres,m_pres,3);

for i=1:valg_npoints_stream
	param_g_sum_suction(:,i) = spline(param_f_sum(:,i),param_g_sum(:,i),suction_side_f_param(:,i));
	param_h_sum_suction(:,i) = spline(param_f_sum(:,i),param_h_sum(:,i),suction_side_f_param(:,i));
	param_f_sum_suction(:,i) = spline(param_f_sum(:,i),sqrt(param_g_sum(:,i).^2+param_h_sum(:,i).^2),suction_side_f_param(:,i));
	
	suction_nodes(:,i,1) = spline(param_g_sum(:,i),x(:,i),param_g_sum_suction(:,i));
	suction_nodes(:,i,2) = spline(param_g_sum(:,i),y(:,i),param_g_sum_suction(:,i));
	suction_nodes(:,i,3) = spline(param_g_sum(:,i),z(:,i),param_g_sum_suction(:,i));
	
	param_g_sum_pressure(:,i) = spline(param_f_sum(:,i),param_g_sum(:,i),pressure_side_f_param(:,i));
	param_h_sum_pressure(:,i) = spline(param_f_sum(:,i),param_h_sum(:,i),pressure_side_f_param(:,i));
	param_f_sum_pressure(:,i) = spline(param_f_sum(:,i),sqrt(param_g_sum(:,i).^2+param_h_sum(:,i).^2),pressure_side_f_param(:,i));
	
	pressure_nodes(:,i,1) = spline(param_g_sum(:,i),x(:,i),param_g_sum_pressure(:,i));
	pressure_nodes(:,i,2) = spline(param_g_sum(:,i),y(:,i),param_g_sum_pressure(:,i));
	pressure_nodes(:,i,3) = spline(param_g_sum(:,i),z(:,i),param_g_sum_pressure(:,i));
end


[suction_nodes_pol(:,:,2),suction_nodes_pol(:,:,1),suction_nodes_pol(:,:,3) ] ...
		= cart2pol(suction_nodes(:,:,1),suction_nodes(:,:,2),suction_nodes(:,:,3));
suction_nodes_pol(:,:,2) = -suction_nodes_pol(:,:,2)*180/pi+90;
[pressure_nodes_pol(:,:,2),pressure_nodes_pol(:,:,1),pressure_nodes_pol(:,:,3) ] ...
		= cart2pol(pressure_nodes(:,:,1),pressure_nodes(:,:,2),pressure_nodes(:,:,3));
pressure_nodes_pol(:,:,2) = -pressure_nodes_pol(:,:,2)*180/pi+90;

nvanes    = length(hand_surf_vanes);
[n,m]     = size(get(hand_surf_vanes(1),'XData'));
suct_surf = zeros(n_suct,m_suct,3,nvanes);
pres_surf = zeros(n_pres,m_pres,3,nvanes);

for i=1:nvanes
    [norm_x_suct(:,:,i),norm_y_suct(:,:,i),norm_z_suct(:,:,i)] = ...
        surfnorm(suction_nodes(:,:,1),suction_nodes(:,:,2),suction_nodes(:,:,3));
    suct_surf(:,:,1,i) = suction_nodes(:,:,1)- norm_x_suct(:,:,i).*suction_side_thickness(:,:);
    suct_surf(:,:,2,i) = suction_nodes(:,:,2)- norm_y_suct(:,:,i).*suction_side_thickness(:,:);
    suct_surf(:,:,3,i) = suction_nodes(:,:,3)- norm_z_suct(:,:,i).*suction_side_thickness(:,:);


    [norm_x_pres(:,:,i),norm_y_pres(:,:,i),norm_z_pres(:,:,i)] = ...
        surfnorm(pressure_nodes(:,:,1),pressure_nodes(:,:,2),pressure_nodes(:,:,3));
    pres_surf(:,:,1,i) = pressure_nodes(:,:,1)-norm_x_pres(:,:,i).*pressure_side_thickness(:,:);
    pres_surf(:,:,2,i) = pressure_nodes(:,:,2)-norm_y_pres(:,:,i).*pressure_side_thickness(:,:);
    pres_surf(:,:,3,i) = pressure_nodes(:,:,3)-norm_z_pres(:,:,i).*pressure_side_thickness(:,:);

end

suct_surf_pol = zeros(n_suct,m_suct,3);
pres_surf_pol = zeros(n_pres,m_pres,3);

[suct_surf_pol(:,:,2), suct_surf_pol(:,:,1), suct_surf_pol(:,:,3)] = cart2pol(suct_surf(:,:,1),suct_surf(:,:,2),suct_surf(:,:,3));
[pres_surf_pol(:,:,2), pres_surf_pol(:,:,1), pres_surf_pol(:,:,3)] = cart2pol(pres_surf(:,:,1),pres_surf(:,:,2),pres_surf(:,:,3));
suct_surf_pol(:,:,2) = -suct_surf_pol(:,:,2)*180/pi+90;
pres_surf_pol(:,:,2) = -pres_surf_pol(:,:,2)*180/pi+90;

% quiver3(suct_surf(:,:,1),suct_surf(:,:,2),suct_surf(:,:,3),norm_x_suct(:,:,1),norm_y_suct(:,:,1),norm_z_suct(:,:,1));
% quiver3(pres_surf(:,:,1),pres_surf(:,:,2),pres_surf(:,:,3),norm_x_pres(:,:,1),norm_y_pres(:,:,1),norm_z_pres(:,:,1));


[hand_axes_3Dview] = update_vanes(hand_axes_3Dview,hand_surf_vanes,valg_design_Z,param_Z_drawn,suct_surf_pol);
[hand_axes_3Dview] = update_vanes(hand_axes_3Dview,hand_surf_vanes,valg_design_Z,param_Z_drawn,pres_surf_pol);


%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
%	Update the vane thickness plot
%ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
param_plot_f_param   = [suction_side_f_param(:,1);  pressure_side_f_param(:,1)  ];
param_plot_thickness = [suction_side_thickness(:,1); pressure_side_thickness(:,1)];

suct_plot_f_param =  0.5*ones(length(suction_side_f_param(:,1)),1) *max(valg_design_tin,valg_design_tout);
pres_plot_f_param = -0.5*ones(length(pressure_side_f_param(:,1)),1)*max(valg_design_tin,valg_design_tout);

set(hand_plot_thickness,'XData',param_plot_f_param,'YData',param_plot_thickness);
set(hand_plot_f_param_suct,'XData',suction_side_f_param(:,1), 'YData',suct_plot_f_param);
set(hand_plot_f_param_pres,'XData',pressure_side_f_param(:,1),'YData',pres_plot_f_param);